% Auto-generated chapter 12 for ibnmajah
% Hadiths in this chapter: 171

\hadithdefcmd{ibnmajah}{2137}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلَ الرَّجُلُ مِنْ كَسْبِهِ وَإِنَّ وَلَدَهُ مِنْ كَسْبِهِ ‏"‏ ‏.‏\hadithno{2137}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:'The best (most pure) food a man consumes is that which he has earned himself, and his child (and his child's wealth) is part of his earnings}}
\hadithdefcmd{ibnmajah}{2138}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ الزُّبَيْدِيِّ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا كَسَبَ الرَّجُلُ كَسْبًا أَطْيَبَ مِنْ عَمَلِ يَدِهِ وَمَا أَنْفَقَ الرَّجُلُ عَلَى نَفْسِهِ وَأَهْلِهِ وَوَلَدِهِ وَخَادِمِهِ فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2138}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Miqdam bin Ma'dikarib (Ar- Zubaidi) that the Messenger of Allah (ﷺ) said:"No man earns anything better than that which he earns with his own hands, and what a man spends on himself, his wife, his child and his servant, then it is charity}}
\hadithdefcmd{ibnmajah}{2139}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا كُلْثُومُ بْنُ جَوْشَنٍ الْقُشَيْرِيُّ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ التَّاجِرُ الأَمِينُ الصَّدُوقُ الْمُسْلِمُ مَعَ الشُّهَدَاءِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2139}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:'The trustworthy, honest Muslim merchant will be with the martyrs on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{2140}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، مَوْلَى ابْنِ مُطِيعٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ السَّاعِي عَلَى الأَرْمَلَةِ وَالْمِسْكِينِ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ وَكَالَّذِي يَقُومُ اللَّيْلَ وَيَصُومُ النَّهَارَ ‏"‏ ‏.‏\hadithno{2140}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:'The one who strives to support the widow and the poor is like a Mujahid who fights in the cause of Allah, and like one who stands in the night (in voluntary prayer) and fasts by day}}
\hadithdefcmd{ibnmajah}{2141}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سُلَيْمَانَ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ أَبِيهِ، عَنْ عَمِّهِ، قَالَ كُنَّا فِي مَجْلِسٍ فَجَاءَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَعَلَى رَأْسِهِ أَثَرُ مَاءٍ فَقَالَ لَهُ بَعْضُنَا نَرَاكَ الْيَوْمَ طَيِّبَ النَّفْسِ ‏.‏ فَقَالَ ‏"‏ أَجَلْ وَالْحَمْدُ لِلَّهِ ‏"‏ ‏.‏ ثُمَّ أَفَاضَ الْقَوْمُ فِي ذِكْرِ الْغِنَى فَقَالَ ‏"‏ لاَ بَأْسَ بِالْغِنَى لِمَنِ اتَّقَى وَالصِّحَّةُ لِمَنِ اتَّقَى خَيْرٌ مِنَ الْغِنَى وَطِيبُ النَّفْسِ مِنَ النِّعَمِ ‏"‏ ‏.‏\hadithno{2141}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mu'adh bin 'Abdullah bin Khubaib, from his father, that his paternal uncle said:"We were sitting in a gathering, and the Prophet (ﷺ) came with traces of water on his head. One of us said to him: 'We see that you are of good cheer today.' He said: 'Yes, praise is to Allah.' Then he spoke to the people about being rich. He said: 'There is nothing wrong with being rich for one who has piety, but good health for one who has piety is better than riches, and being of good cheer is a blessing}}
\hadithdefcmd{ibnmajah}{2142}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَجْمِلُوا فِي طَلَبِ الدُّنْيَا فَإِنَّ كُلاًّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏\hadithno{2142}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Humaid As-Sa'idi that the Messenger of Allah (ﷺ) said:Be moderate in seeking worldly things, for everyone will be facilitated for which he was created}}
\hadithdefcmd{ibnmajah}{2143}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ بَهْرَامَ، حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ عُثْمَانَ، زَوْجُ بِنْتِ الشَّعْبِيِّ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَعْظَمُ النَّاسِ هَمًّا الْمُؤْمِنُ الَّذِي يَهُمُّ بِأَمْرِ دُنْيَاهُ وَأَمْرِ آخِرَتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هَذَا حَدِيثٌ غَرِيبٌ تَفَرَّدَ بِهِ إِسْمَاعِيلُ ‏.‏\hadithno{2143}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:The one who has the most concerns is the believer who is concerned about both his worldly affairs and his Hereafter."' (Da'if)Abu 'Abdullah said: "This Hadith is Gharib' Isma'il, alone, has narrated it}}
\hadithdefcmd{ibnmajah}{2144}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَيُّهَا النَّاسُ اتَّقُوا اللَّهَ وَأَجْمِلُوا فِي الطَّلَبِ فَإِنَّ نَفْسًا لَنْ تَمُوتَ حَتَّى تَسْتَوْفِيَ رِزْقَهَا وَإِنْ أَبْطَأَ عَنْهَا فَاتَّقُوا اللَّهَ وَأَجْمِلُوا فِي الطَّلَبِ خُذُوا مَا حَلَّ وَدَعُوا مَا حَرُمَ ‏"‏ ‏.‏\hadithno{2144}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:"O people, fear Allah and be moderate in seeking a living, for no soul will die until it has received all its provision, even if it is slow in coming. So fear Allah and be moderate in seeking provision; take that which is permissible and leave that which is forbidden}}
\hadithdefcmd{ibnmajah}{2145}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا نُسَمَّى فِي عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ السَّمَاسِرَةَ فَمَرَّ بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَمَّانَا بِاسْمٍ هُوَ أَحْسَنُ مِنْهُ فَقَالَ ‏ "‏ يَا مَعْشَرَ التُّجَّارِ إِنَّ الْبَيْعَ يَحْضُرُهُ الْحَلِفُ وَاللَّغْوُ فَشُوبُوهُ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{2145}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin Abu Gharazah said:"At the time of the Messenger of Allah (ﷺ) we used to be called brokers, but the Messenger of Allah (ﷺ) passed by us and called by a name that was better than that. He said: 'O merchants, selling involves (false) oaths and idle talk, so mix some charity with it}}
\hadithdefcmd{ibnmajah}{2146}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رِفَاعَةَ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَإِذَا النَّاسُ يَتَبَايَعُونَ بُكْرَةً فَنَادَاهُمْ ‏"‏ يَا مَعْشَرَ التُّجَّارِ ‏"‏ ‏.‏ فَلَمَّا رَفَعُوا أَبْصَارَهُمْ وَمَدُّوا أَعْنَاقَهُمْ قَالَ ‏"‏ إِنَّ التُّجَّارَ يُبْعَثُونَ يَوْمَ الْقِيَامَةِ فُجَّارًا إِلاَّ مَنِ اتَّقَى اللَّهَ وَبَرَّ وَصَدَقَ ‏"‏ ‏.‏\hadithno{2146}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Isma'il bin 'Ubaid bin Rifa'ah, from his father, that his grandfather Rifa'ah said:"We went out with the Messenger of Allah (ﷺ) and the people were trading early in the morning. He called them: 'O merchants!' and when they looked up and craned their necks, he said : 'The merchants will be raised on the Day of Resurrection as immoral people, apart from those who fear Allah and act righteously and speak the truth (i.e. those who are honest)}}
\hadithdefcmd{ibnmajah}{2147}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا فَرْوَةُ أَبُو يُونُسَ، عَنْ هِلاَلِ بْنِ جُبَيْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَصَابَ مِنْ شَىْءٍ فَلْيَلْزَمْهُ ‏"‏ ‏.‏\hadithno{2147}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:'Whoever achieves at something, let him stick with It}}
\hadithdefcmd{ibnmajah}{2148}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنِي أَبِي، عَنِ الزُّبَيْرِ بْنِ عُبَيْدٍ، عَنْ نَافِعٍ، قَالَ كُنْتُ أُجَهِّزُ إِلَى الشَّامِ وَإِلَى مِصْرَ فَجَهَّزْتُ إِلَى الْعِرَاقِ فَأَتَيْتُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ فَقُلْتُ لَهَا يَا أُمَّ الْمُؤْمِنِينَ كُنْتُ أُجَهِّزُ إِلَى الشَّامِ فَجَهَّزْتُ إِلَى الْعِرَاقِ ‏.‏ فَقَالَتْ لاَ تَفْعَلْ مَالَكَ وَلِمَتْجَرِكَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا سَبَّبَ اللَّهُ لأَحَدِكُمْ رِزْقًا مِنْ وَجْهٍ فَلاَ يَدَعْهُ حَتَّى يَتَغَيَّرَ لَهُ أَوْ يَتَنَكَّرَ لَهُ ‏"‏ ‏.‏\hadithno{2148}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Nafi' said:I used to send trade goods to Sham and Egypt, then I prepared to send trade goods to 'Iraq. I went to 'Aishah, the Mother of the Believers, and said to her: " O Mother of the Believers I used to send trade goods to Sham and I am preparing to send trade goods to 'Iraq." She said: "Do not do that. What is wrong with the way you have been doing it? I heard the Messenger of Allah (ﷺ) say: 'If Allah causes provision to come to one of you through a certain means, he should not leave it unless it changes or deteriorates}}
\hadithdefcmd{ibnmajah}{2149}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدٍ الْقُرَشِيُّ، عَنْ جَدِّهِ، سَعِيدِ بْنِ أَبِي أُحَيْحَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَا بَعَثَ اللَّهُ نَبِيًّا إِلاَّ رَاعِيَ غَنَمٍ ‏"‏ ‏.‏ قَالَ لَهُ أَصْحَابُهُ وَأَنْتَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَأَنَا كُنْتُ أَرْعَاهَا لأَهْلِ مَكَّةَ بِالْقَرَارِيطِ ‏"‏ ‏.‏ قَالَ سُوَيْدٌ يَعْنِي كُلُّ شَاةٍ بِقِيرَاطٍ ‏.‏\hadithno{2149}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Allah has not sent any Prophet but he was a shepherd." His Companions said to him: "Even you, O Messenger of Allah?" He said: "Even me I used to tend the sheep of the people of Makkah for a few Qirats." (Sahih)(One of the narrators) Suwaid said: " Meaning one Qirat for every sheep}}
\hadithdefcmd{ibnmajah}{2150}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، وَالْحَجَّاجُ، وَالْهَيْثَمُ بْنُ جَمِيلٍ، قَالُوا حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَانَ زَكَرِيَّا نَجَّارًا ‏"‏ ‏.‏\hadithno{2150}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Zakariyya was a carpenter}}
\hadithdefcmd{ibnmajah}{2151}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أَصْحَابَ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏\hadithno{2151}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"The image-makers will be punished on the Day of Resurrection and will be told: 'Give life to that which you have created}}
\hadithdefcmd{ibnmajah}{2152}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عُمَرُ بْنُ هَارُونَ، عَنْ هَمَّامٍ، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَكْذَبُ النَّاسِ الصَّبَّاغُونَ وَالصَّوَّاغُونَ ‏"‏ ‏.‏\hadithno{2152}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The most dishonest of people are the dyers and the goldsmiths}}
\hadithdefcmd{ibnmajah}{2153}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عَلِيِّ بْنِ سَالِمِ بْنِ ثَوْبَانَ، عَنْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْجَالِبُ مَرْزُوقٌ وَالْمُحْتَكِرُ مَلْعُونٌ ‏"‏ ‏.‏\hadithno{2153}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Umar bin Khattab that the Messenger of Allah (ﷺ) said:"The importer is blessed with provision and the hoarder is cursed}}
\hadithdefcmd{ibnmajah}{2154}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ مَعْمَرِ بْنِ عَبْدِ اللَّهِ بْنِ نَضْلَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَحْتَكِرُ إِلاَّ خَاطِئٌ ‏"‏ ‏.‏\hadithno{2154}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ma'mar bin 'Abdullah bin Nadlah that the Messenger of Allah (ﷺ) said:"No one hoards but a sinner}}
\hadithdefcmd{ibnmajah}{2155}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الْهَيْثَمُ بْنُ رَافِعٍ، حَدَّثَنِي أَبُو يَحْيَى الْمَكِّيُّ، عَنْ فَرُّوخَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنِ احْتَكَرَ عَلَى الْمُسْلِمِينَ طَعَامَهُمْ ضَرَبَهُ اللَّهُ بِالْجُذَامِ وَالإِفْلاَسِ ‏"‏ ‏.‏\hadithno{2155}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Umar bin Khattab said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever hoards food (and keeps it from) the Muslims, Allah will afflict him with leprosy and bankruptcy}}
\hadithdefcmd{ibnmajah}{2156}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ثَلاَثِينَ رَاكِبًا فِي سَرِيَّةٍ فَنَزَلْنَا بِقَوْمٍ فَسَأَلْنَاهُمْ أَنْ يَقْرُونَا فَأَبَوْا فَلُدِغَ سَيِّدُهُمْ فَأَتَوْنَا فَقَالُوا أَفِيكُمْ أَحَدٌ يَرْقِي مِنَ الْعَقْرَبِ فَقُلْتُ نَعَمْ أَنَا وَلَكِنْ لاَ أَرْقِيهِ حَتَّى تُعْطُونَا غَنَمًا ‏.‏ قَالُوا فَإِنَّا نُعْطِيكُمْ ثَلاَثِينَ شَاةً ‏.‏ فَقَبِلْنَاهَا فَقَرَأْتُ عَلَيْهِ ‏(‏ الْحَمْدُ ‏)‏ سَبْعَ مَرَّاتٍ فَبَرِئَ وَقَبَضْنَا الْغَنَمَ فَعَرَضَ فِي أَنْفُسِنَا مِنْهَا شَىْءٌ فَقُلْنَا لاَ تَعْجَلُوا حَتَّى نَأْتِيَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَلَمَّا قَدِمْنَا ذَكَرْتُ لَهُ الَّذِي صَنَعْتُ فَقَالَ ‏ "‏ أَوَ مَا عَلِمْتَ أَنَّهَا رُقْيَةٌ اقْتَسِمُوهَا وَاضْرِبُوا لِي مَعَكُمْ سَهْمًا ‏"‏ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَالصَّوَابُ هُوَ أَبُو الْمُتَوَكِّلِ إِنْ شَاءَ اللَّهُ ‏.‏\hadithno{2156}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah (ﷺ) sent us, thirty horsemen, on a military campaign. We camped near some people and asked them for hospitality but they refused. Then their leader was stung by a scorpion and they said: 'Is there anyone among you who can recite Ruqyah for a scorpion sting?' I said: 'Yes, I can, but I will not recite Ruqyah for him until you give us some sheep.' They said: 'We will give you thirty sheep.' So we accepted them, and I recited Al-Hamd (i.e. Al-Fatihah) over him seven times. Then he recovered, and I took the sheep. Then some doubts occurred within ourselves. Then we said: 'Let us not hasten (to make a decision concerning the sheep) until we come to the Prophet (ﷺ)' So when we came back: 'I told him what I had done. He said: 'How did you know that it is a Ruqyah? Divide them up and give me a share as well}}
\hadithdefcmd{ibnmajah}{2157}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مُغِيرَةُ بْنُ زِيَادٍ الْمَوْصِلِيُّ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنِ الأَسْوَدِ بْنِ ثَعْلَبَةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ عَلَّمْتُ نَاسًا مِنْ أَهْلِ الصُّفَّةِ الْقُرْآنَ وَالْكِتَابَةَ فَأَهْدَى إِلَىَّ رَجُلٌ مِنْهُمْ قَوْسًا فَقُلْتُ لَيْسَتْ بِمَالٍ وَأَرْمِي عَنْهَا فِي سَبِيلِ اللَّهِ فَسَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْهَا فَقَالَ ‏ "‏ إِنْ سَرَّكَ أَنْ تُطَوَّقَ بِهَا طَوْقًا مِنْ نَارٍ فَاقْبَلْهَا ‏"‏ ‏.‏\hadithno{2157}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Ubadah bin Samit said:"I taught people from Ahtus-Suffah" Qur'an and how to write, and one of them gave me a bow. I said: 'It is not money, and I can shoot (with it) for the sake of Allah., I asked the Messenger of Allah (ﷺ) about it and he said: 'If it would please you to have a necklace of fire placed around your neck, then accept it}}
\hadithdefcmd{ibnmajah}{2158}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، حَدَّثَنَا خَالِدُ بْنُ مَعْدَانَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ سَلْمٍ، عَنْ عَطِيَّةَ الْكَلاَعِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ عَلَّمْتُ رَجُلاً الْقُرْآنَ فَأَهْدَى إِلَىَّ قَوْسًا فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنْ أَخَذْتَهَا أَخَذْتَ قَوْسًا مِنْ نَارٍ ‏"‏ ‏.‏ فَرَدَدْتُهَا ‏.‏\hadithno{2158}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ubayy bin Ka'b said:"I taught a man the Qur'an, and he gave me a bow. I mentioned that to the Messenger of Allah (ﷺ) and he said: 'If you accept it you will be accepting a bow of fire.' So I returned it}}
\hadithdefcmd{ibnmajah}{2159}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏\hadithno{2159}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Mas'ud that :the Prophet (ﷺ) forbade the price of a dog, the payment (given to a prostitute) and the payment made to a soothsayer}}
\hadithdefcmd{ibnmajah}{2160}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ طَرِيفٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ثَمَنِ الْكَلْبِ وَعَسْبِ الْفَحْلِ‏.‏\hadithno{2160}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) forbade the price of a dog and studding a stallion}}
\hadithdefcmd{ibnmajah}{2161}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ ثَمَنِ السِّنَّوْرِ ‏.‏\hadithno{2161}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{lt was narrated from Abu Az-Zubair that Jabir said:"The Messenger of Allah (ﷺ) forbade the price of a cat}}
\hadithdefcmd{ibnmajah}{2162}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ احْتَجَمَ وَأَعْطَاهُ أَجْرَهُ ‏.‏ قَالَ ابْنُ مَاجَهْ تَفَرَّدَ بِهِ ابْنُ أَبِي عُمَرَ وَحْدَهُ ‏.‏\hadithno{2162}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that :the Prophet (ﷺ) was treated with cupping and he gave him (the cupper) his wages. (Sahih)Ibn Abu 'Umar was alone in narrating it. That was said by Ibn Majah}}
\hadithdefcmd{ibnmajah}{2163}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ أَبُو حَفْصٍ الصَّيْرَفِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالاَ حَدَّثَنَا وَرْقَاءُ، عَنْ عَبْدِ الأَعْلَى، عَنْ أَبِي جَمِيلَةَ عَنْ عَلِيٍّ، قَالَ احْتَجَمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَمَرَنِي فَأَعْطَيْتُ الْحَجَّامَ أَجْرَهُ ‏.‏\hadithno{2163}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) was treated with cupping and he told me to give the cupper his wages}}
\hadithdefcmd{ibnmajah}{2164}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ يُونُسَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ احْتَجَمَ وَأَعْطَى الْحَجَّامَ أَجْرَهُ ‏.‏\hadithno{2164}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that:the Prophet (ﷺ) was treated with cupping and gave the cupper his wages}}
\hadithdefcmd{ibnmajah}{2165}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي مَسْعُودٍ، عُقْبَةَ بْنِ عَمْرٍو قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ كَسْبِ الْحَجَّامِ ‏.‏\hadithno{2165}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mas'ud, 'Uqbah bin 'Amr, said:"The Messenger of Allah (ﷺ), forbade the earnings of a cupper}}
\hadithdefcmd{ibnmajah}{2166}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ حَرَامِ بْنِ مُحَيِّصَةَ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنْ كَسْبِ الْحَجَّامِ فَنَهَاهُ عَنْهُ فَذَكَرَ لَهُ الْحَاجَةَ فَقَالَ ‏ "‏ اعْلِفْهُ نَوَاضِحَكَ ‏"‏ ‏.‏\hadithno{2166}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Haram bin Munayyisah that :his father asked the Prophet (ﷺ) about the earnings of a cupper and he forbade him from that. Then he mentioned his need and he said: "Spend it on feeding your she-camels that draw water}}
\hadithdefcmd{ibnmajah}{2167}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّهُ قَالَ قَالَ عَطَاءُ بْنُ أَبِي رَبَاحٍ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ لَهُ عِنْدَ ذَلِكَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُدْهَنُ بِهَا السُّفُنُ وَيُدْهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ قَالَ ‏"‏ لاَ هُنَّ حَرَامٌ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ حَرَّمَ عَلَيْهِمُ الشُّحُومَ فَأَجْمَلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{2167}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ata' bin Abu Rabah said:I heard Jabir bin 'Abdullah say: "In the Year of the Conquest, while he was in Makkah the Messenger of Allah (ﷺ), said: 'Allah and His Messenger have forbidden the sale of wines, meat of dead animals, pigs and 'idols.' It was said to him: 'O Messenger of Allah, what do you think of the fat of dead animals, for it is used to caulk ships, it is daubed on animal skins and people use it to light their lamps?' He said: 'No, it is unlawful.' Then the Messenger of Allah (ﷺ) said: 'May Allah curse the jews, for Allah forbade them the fat (of animals) but they rendered it, (i.e. melted it) sold it and consumed its price}}
\hadithdefcmd{ibnmajah}{2168}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنْ عَاصِمٍ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عُبَيْدِ اللَّهِ الإِفْرِيقِيِّ، عَنْ أَبِي أُمَامَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعِ الْمُغَنِّيَاتِ وَعَنْ شِرَائِهِنَّ وَعَنْ كَسْبِهِنَّ وَعَنْ أَكْلِ أَثْمَانِهِنَّ ‏.‏\hadithno{2168}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah said:"The Messenger of Allah, forbade selling or buying singing girls, and their wages, and consuming their price}}
\hadithdefcmd{ibnmajah}{2169}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعَتَيْنِ عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏\hadithno{2169}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) forbade two kinds of transactions: Mulimasah and Mundbadhah}}
\hadithdefcmd{ibnmajah}{2170}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏ زَادَ سَهْلٌ قَالَ سُفْيَانُ الْمُلاَمَسَةُ أَنْ يَلْمِسَ الرَّجُلُ الشَّىْءَ بِيَدِهِ وَلاَ يَرَاهُ وَالْمُنَابَذَةُ أَنْ يَقُولَ أَلْقِ إِلَىَّ مَا مَعَكَ وَأُلْقِي إِلَيْكَ مَا مَعِي ‏.‏\hadithno{2170}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that :the Messenger of Allah (ﷺ) forbade Mulamasah and Munabadhah. (Sahih) Sahl added: "Sufyan said: 'Mulamasah means when a man touches something with his hand without seeing it, and Munabadhah means when he says: "Toss me what you have, and I will toss you what have}}
\hadithdefcmd{ibnmajah}{2171}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَبِيعُ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ ‏"‏ ‏.‏\hadithno{2171}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Let one of you not undersell another}}
\hadithdefcmd{ibnmajah}{2172}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَبِيعُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَسُومُ عَلَى سَوْمِ أَخِيهِ ‏"‏ ‏.‏\hadithno{2172}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{lt was narrated from Abu Hurairah that the Prophet (ﷺ) said:"A man is not to undersell his brother, nor is he to fry to outhaggle his brother}}
\hadithdefcmd{ibnmajah}{2173}{قَرَأْتُ عَلَى مُصْعَبِ بْنِ عَبْدِ اللَّهِ الزُّبَيْرِيِّ عَنْ مَالِكٍ، ح وَحَدَّثَنَا أَبُو حُذَافَةَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنِ النَّجْشِ ‏.‏\hadithno{2173}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that :the Prophet (ﷺ) forbade the Najsh}}
\hadithdefcmd{ibnmajah}{2174}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَنَاجَشُوا ‏"‏ ‏.‏\hadithno{2174}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Do not practice Najsh}}
\hadithdefcmd{ibnmajah}{2175}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ ‏"‏ ‏.‏\hadithno{2175}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"A City-dweller should not sell for a Bedouin}}
\hadithdefcmd{ibnmajah}{2176}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ دَعُوا النَّاسَ يَرْزُقُ اللَّهُ بَعْضَهُمْ مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{2176}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Prophet (ﷺ) said:"A city-dweller should not sell for a Bedouin. Leave people to (engage in trade) and Allah will grant them provision through one another}}
\hadithdefcmd{ibnmajah}{2177}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏ قُلْتُ لاِبْنِ عَبَّاسٍ مَا قَوْلُهُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُونُ لَهُ سِمْسَارًا ‏.‏\hadithno{2177}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Tawus narrated from his father that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) forbade a city-dweller to sell for a Bedouin." (Sahih)I (Tawus) said to Ibn 'Abbas: "What is meant by the words: 'A city-dweller selling for a Bedouin?' He said: "He should not be a broker for him}}
\hadithdefcmd{ibnmajah}{2178}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَلَقَّوُا الأَجْلاَبَ فَمَنْ تَلَقَّى مِنْهُ شَيْئًا فَاشْتَرَى فَصَاحِبُهُ بِالْخِيَارِ إِذَا أَتَى السُّوقَ ‏"‏ ‏.‏\hadithno{2178}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Do not meet the traders on the way, and whoever meets any of them and buys from him, the vendor has the choice of annulling the transaction when he comes to the marketplace}}
\hadithdefcmd{ibnmajah}{2179}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ تَلَقِّي الْجَلَبِ ‏.‏\hadithno{2179}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) forbade meeting traders on the way}}
\hadithdefcmd{ibnmajah}{2180}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَحَمَّادُ بْنُ مَسْعَدَةَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ بْنِ الشَّهِيدِ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَبُو عُثْمَانَ النَّهْدِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ تَلَقِّي الْبُيُوعِ ‏.‏\hadithno{2180}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Messenger of Allah (ﷺ) forbade. meeting the owners of goods (away from the market)}}
\hadithdefcmd{ibnmajah}{2181}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا تَبَايَعَ الرَّجُلاَنِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا وَكَانَا جَمِيعًا أَوْ يُخَيِّرْ أَحَدُهُمَا الآخَرَ فَإِنْ خَيَّرَ أَحَدُهُمَا الآخَرَ فَتَبَايَعَا عَلَى ذَلِكَ فَقَدْ وَجَبَ الْبَيْعُ ‏.‏ وَإِنْ تَفَرَّقَا بَعْدَ أَنْ تَبَايَعَا وَلَمْ يَتْرُكْ وَاحِدٌ مِنْهُمَا الْبَيْعَ فَقَدْ وَجَبَ الْبَيْعُ ‏"‏ ‏.‏\hadithno{2181}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah said:"When two men enter into a transaction, each of them has the choice (of annulling it) so long as they have not yet parted and are still together, or one of them has given the option or choice to the other. Once he has accepted the terms of the other, then the transaction is binding. If they part after concluding the transaction and neither of them has rescinded the transaction then the transaction is binding.”}}
\hadithdefcmd{ibnmajah}{2182}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَأَحْمَدُ بْنُ الْمِقْدَامِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ جَمِيلِ بْنِ مُرَّةَ، عَنْ أَبِي الْوَضِيءِ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ‏"‏ ‏.‏\hadithno{2182}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Barzah Al-Aslami that the Messenger of Allah (ﷺ) said:”The two parties to a transaction have the choice (of annulling it) so long as they have not yet parted}}
\hadithdefcmd{ibnmajah}{2183}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا ‏"‏ ‏.‏\hadithno{2183}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Samurah that the Messenger of Allah (ﷺ) said:"The two parties to a transaction have the choice (of annulling it) so long as they have not yet parted}}
\hadithdefcmd{ibnmajah}{2184}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عِيسَى الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ اشْتَرَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ رَجُلٍ مِنَ الأَعْرَابِ حِمْلَ خَبَطٍ فَلَمَّا وَجَبَ الْبَيْعُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اخْتَرْ ‏"‏ ‏.‏ فَقَالَ الأَعْرَابِيُّ عَمْرَكَ اللَّهَ بَيِّعًا ‏.‏\hadithno{2184}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin' Abdullah said:"The Messenger of Allah (ﷺ) bought a load of fodder from a Bedouin man. When the transaction was concluded, the Messenger of Allah (ﷺ) said: 'Choose (either to go ahead or to cancel the transaction).' The Bedouin said: 'May Allah grant you a long life of good transaction}}
\hadithdefcmd{ibnmajah}{2185}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ دَاوُدَ بْنِ صَالِحٍ الْمَدَنِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا الْبَيْعُ عَنْ تَرَاضٍ ‏"‏ ‏.‏\hadithno{2185}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Dawud bin Salih Al Madani that his father said:I heard Abu Sa'eed Al-Khudri say: "The Messenger of Allah (ﷺ) said: 'Transactions may only be done by mutual consent}}
\hadithdefcmd{ibnmajah}{2186}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا ابْنُ أَبِي لَيْلَى، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، بَاعَ مِنَ الأَشْعَثِ بْنِ قَيْسٍ رَقِيقًا مِنْ رَقِيقِ الإِمَارَةِ فَاخْتَلَفَا فِي الثَّمَنِ ‏.‏ فَقَالَ ابْنُ مَسْعُودٍ بِعْتُكَ بِعِشْرِينَ أَلْفًا ‏.‏ وَقَالَ الأَشْعَثُ بْنُ قَيْسٍ إِنَّمَا اشْتَرَيْتُ مِنْكَ بِعَشْرَةِ آلاَفٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ إِنْ شِئْتَ حَدَّثْتُكَ بِحَدِيثٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ هَاتِهِ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا اخْتَلَفَ الْبَيِّعَانِ وَلَيْسَ بَيْنَهُمَا بَيِّنَةٌ وَالْبَيْعُ قَائِمٌ بِعَيْنِهِ فَالْقَوْلُ مَا قَالَ الْبَائِعُ أَوْ يَتَرَادَّانِ الْبَيْعَ ‏"‏ ‏.‏ قَالَ فَإِنِّي أَرَى أَنْ أَرُدَّ الْبَيْعَ ‏.‏ فَرَدَّهُ ‏.‏\hadithno{2186}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Qasim bin 'Abdur Rahman from his father that :Abdullah bin Mas'ud sold one of the slaves from the state[1] to Ash'ath bin Qais, and they differed concerning the price. Ibn Mas'ud said: "I sold him to you for twenty thousand,' but Ash'ath bin Qais said: "I bought him from you for ten thousand." 'Abdullah said: "If you want, I will tell you a Hadith which I heard from the Messenger of Allah (ﷺ)" He said: "Tell me it." He said: "I heard the Messenger of Allah (ﷺ) say: 'If two parties to a transaction differ, and they have no proof, and the sale item remains (unredeemed), then what the seller says is valid. Or they may cancel the transaction." He said: "I want to cancel the transaction." And he cancelled it}}
\hadithdefcmd{ibnmajah}{2187}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ يُوسُفَ بْنَ مَاهَكَ، يُحَدِّثُ عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ الرَّجُلُ يَسْأَلُنِي الْبَيْعَ وَلَيْسَ عِنْدِي أَفَأَبِيعُهُ قَالَ ‏ "‏ لاَ تَبِعْ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏\hadithno{2187}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hakim bin Hizam said:"I said: 'O Messenger of Allah, a man is asking me to sell him something that I do not possess; Shall I sell it to him?' He said: 'Do not sell what is not with you}}
\hadithdefcmd{ibnmajah}{2188}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالاَ حَدَّثَنَا أَيُّوبُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَحِلُّ بَيْعُ مَا لَيْسَ عِنْدَكَ وَلاَ رِبْحُ مَا لَمْ يُضْمَنْ ‏"‏ ‏.‏\hadithno{2188}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"The Messenger of Allah (ﷺ) said: 'It is not permissible to sell something that is not with you, nor to profit from what you do not possess}}
\hadithdefcmd{ibnmajah}{2189}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ لَيْثٍ، عَنْ عَطَاءٍ، عَنْ عَتَّابِ بْنِ أَسِيدٍ، قَالَ لَمَّا بَعَثَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى مَكَّةَ نَهَاهُ عَنْ شِفِّ مَا لَمْ يُضْمَنْ ‏.‏\hadithno{2189}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ata that 'Attab bin Asid said that :when the Messenger of Allah (ﷺ) sent him to Makkah, he forbade him from profiting off of what he did not possess}}
\hadithdefcmd{ibnmajah}{2190}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَوْ سَمُرَةَ بْنِ جُنْدُبٍ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَيُّمَا رَجُلٍ بَاعَ بَيْعًا مِنْ رَجُلَيْنِ فَهُوَ لِلأَوَّلِ مِنْهُمَا ‏"‏ ‏.‏\hadithno{2190}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amir or Samurah bin Jundab that the Messenger of Allah (ﷺ) said:"Any man who sells to two men, it is for the one who was first}}
\hadithdefcmd{ibnmajah}{2191}{حَدَّثَنَا الْحُسَيْنُ بْنُ أَبِي السَّرِيِّ الْعَسْقَلاَنِيُّ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا بَاعَ الْمُجِيزَانِ فَهُوَ لِلأَوَّلِ ‏"‏ ‏.‏\hadithno{2191}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah that the Messenger of Allah (ﷺ), said:"If two (separate) authorized persons make a sale (of the same thing), then the first transaction is the one that is valid}}
\hadithdefcmd{ibnmajah}{2192}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، قَالَ بَلَغَنِي عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ الْعُرْبَانِ ‏.‏\hadithno{2192}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather that :the Prophet (ﷺ) forbade the deal involving earnest money}}
\hadithdefcmd{ibnmajah}{2193}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ الرُّخَامِيُّ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي حَبِيبٍ أَبُو مُحَمَّدٍ، كَاتِبُ مَالِكِ بْنِ أَنَسٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرٍ الأَسْلَمِيُّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ الْعُرْبَانِ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ الْعُرْبَانُ أَنْ يَشْتَرِيَ الرَّجُلُ دَابَّةً بِمِائَةِ دِينَارٍ فَيُعْطِيَهُ دِينَارَيْنِ أَرْبُونًا فَيَقُولَ إِنْ لَمْ أَشْتَرِ الدَّابَّةَ فَالدِّينَارَانِ لَكَ ‏.‏\hadithno{2193}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather that :the Prophet (ﷺ) forbade the deal involving earnest money. (Hasan)Abu 'Abdullah said: Earnest money refers to when a man buys an animal for one hundred Dinar, then he gives the seller two Dinar in advance and says: "If I do not buy the animal, then the two Dinar are yours." And it was said that it refers, and Allah knows best, to when a man buys something, and gives the seller a Dirham or less or more, and says: "If I take it (all well and good), and if I do not, then the Dirham is yours}}
\hadithdefcmd{ibnmajah}{2194}{حَدَّثَنَا مُحْرِزُ بْنُ سَلَمَةَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعِ الْغَرَرِ وَعَنْ بَيْعِ الْحَصَاةِ ‏.‏\hadithno{2194}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) forbade Gharar transaction sand Hasah transactions}}
\hadithdefcmd{ibnmajah}{2195}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَالْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالاَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا أَيُّوبُ بْنُ عُتْبَةَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعِ الْغَرَرِ ‏.‏\hadithno{2195}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) forbade Gharar transactions}}
\hadithdefcmd{ibnmajah}{2196}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَهْضَمُ بْنُ عَبْدِ اللَّهِ الْيَمَامِيُّ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ الْبَاهِلِيِّ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ الْعَبْدِيِّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ شِرَاءِ مَا فِي بُطُونِ الأَنْعَامِ حَتَّى تَضَعَ وَعَمَّا فِي ضُرُوعِهَا إِلاَّ بِكَيْلٍ وَعَنْ شِرَاءِ الْعَبْدِ وَهُوَ آبِقٌ وَعَنْ شِرَاءِ الْمَغَانِمِ حَتَّى تُقْسَمَ وَعَنْ شِرَاءِ الصَّدَقَاتِ حَتَّى تُقْبَضَ وَعَنْ ضَرْبَةِ الْغَائِصِ ‏.‏\hadithno{2196}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:“The Messenger of Allah (ﷺ) forbade selling what is in the wombs of cattle until they give birth, and selling what is in their udders unless it is measured out, and selling a slave who has fled, and selling spoils of war until it has been distributed, and selling Sadaqah until it has been received, and what a diver is going to bring up}}
\hadithdefcmd{ibnmajah}{2197}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏\hadithno{2197}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that :the Prophet (ﷺ) forbade selling Hablul-Habalah}}
\hadithdefcmd{ibnmajah}{2198}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَخْضَرُ بْنُ عَجْلاَنَ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ يَسْأَلُهُ فَقَالَ ‏"‏ لَكَ فِي بَيْتِكَ شَىْءٌ ‏"‏ ‏.‏ قَالَ بَلَى حِلْسٌ نَلْبَسُ بَعْضَهُ وَنَبْسُطُ بَعْضَهُ وَقَدَحٌ نَشْرَبُ فِيهِ الْمَاءَ ‏.‏ قَالَ ‏"‏ ائْتِنِي بِهِمَا ‏"‏ ‏.‏ قَالَ فَأَتَاهُ بِهِمَا فَأَخَذَهُمَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِيَدِهِ ثُمَّ قَالَ ‏"‏ مَنْ يَشْتَرِي هَذَيْنِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا آخُذُهُمَا بِدِرْهَمٍ ‏.‏ قَالَ ‏"‏ مَنْ يَزِيدُ عَلَى دِرْهَمٍ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا قَالَ رَجُلٌ أَنَا آخُذُهُمَا بِدِرْهَمَيْنِ ‏.‏ فَأَعْطَاهُمَا إِيَّاهُ وَأَخَذَ الدِّرْهَمَيْنِ فَأَعْطَاهُمَا الأَنْصَارِيَّ وَقَالَ ‏"‏ اشْتَرِ بِأَحَدِهِمَا طَعَامًا فَانْبِذْهُ إِلَى أَهْلِكَ وَاشْتَرِ بِالآخَرِ قَدُومًا فَأْتِنِي بِهِ ‏"‏ ‏.‏ فَفَعَلَ فَأَخَذَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَشَدَّ فِيهِ عُودًا بِيَدِهِ وَقَالَ ‏"‏ اذْهَبْ فَاحْتَطِبْ وَلاَ أَرَاكَ خَمْسَةَ عَشَرَ يَوْمًا ‏"‏ ‏.‏ فَجَعَلَ يَحْتَطِبُ وَيَبِيعُ فَجَاءَ وَقَدْ أَصَابَ عَشْرَةَ دَرَاهِمَ فَقَالَ ‏"‏ اشْتَرِ بِبَعْضِهَا طَعَامًا وَبِبَعْضِهَا ثَوْبًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ هَذَا خَيْرٌ لَكَ مِنْ أَنْ تَجِيءَ وَالْمَسْأَلَةُ نُكْتَةٌ فِي وَجْهِكَ يَوْمَ الْقِيَامَةِ إِنَّ الْمَسْأَلَةَ لاَ تَصْلُحُ إِلاَّ لِذِي فَقْرٍ مُدْقِعٍ أَوْ لِذِي غُرْمٍ مُفْظِعٍ أَوْ دَمٍ مُوجِعٍ ‏"‏ ‏.‏\hadithno{2198}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that :a man from among the Ansar came to the Prophet (ﷺ) and begged from him. He said, "Do you have anything in your house?" He said: "Yes, a blanket, part of which we cover ourselves with and part we spread beneath us, and a bowl from which we drink water." He said: "Givethem to me." So he brought them to him, and the Messenger of Allah (ﷺ) took them in his hand and said, "Who will by these two things?" A man said: "I will by them for one Dirham." He said: "Who will offer more than a Dirham?" two or three times. A man said: "I will buy them for two Dirham." So he gave them to him and took the two Dirham, which he gave to the Ansari and said: "Buy food with one of them and give it to your family, and buy an axe with the other and bring it to me." So he did that, and the Messenger of Allah (ﷺ) took it and fixed a handle to it, and said: "Go and gather firewood, and I do not want to see you for fifteen days." So he went and gathered firewood and sold it, then he came back, and he had earned ten Dirham. (The Prophet (ﷺ)) said: "Buy food with some of it and clothes with some." Then he said: "This is better for you than coming with begging (appearing) as a spot on your face on the Day of Resurrection. Begging is only appropriate for one who is extremely poor or who is in severe debt, or one who must pay painful blood money.”}}
\hadithdefcmd{ibnmajah}{2199}{حَدَّثَنَا زِيَادُ بْنُ يَحْيَى أَبُو الْخَطَّابِ، حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أَقَالَ مُسْلِمًا أَقَالَهُ اللَّهُ عَثْرَتَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2199}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:Whoever agrees with a Muslim to cancel a transaction Allah will forgive his sins on the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{2200}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، وَحُمَيْدٍ، وَثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ غَلاَ السِّعْرُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالُوا يَا رَسُولَ اللَّهِ قَدْ غَلاَ السِّعْرُ فَسَعِّرْ لَنَا ‏.‏ فَقَالَ ‏ "‏ إِنَّ اللَّهَ هُوَ الْمُسَعِّرُ الْقَابِضُ الْبَاسِطُ الرَّازِقُ إِنِّي لأَرْجُو أَنْ أَلْقَى رَبِّي وَلَيْسَ أَحَدٌ يَطْلُبُنِي بِمَظْلَمَةٍ فِي دَمٍ وَلاَ مَالٍ ‏"‏ ‏.‏\hadithno{2200}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was nanated that Anas bin Malik said:"Prices rose during the time of the Messenger of Allah (ﷺ), and they said: 'O Messenger of Allah, prices have risen, so fix the prices for us.' He said: 'Indeed Allah is the Musa'ir, [1] the Qabid, (Restrainer) the Basit,[2] the Razzaq (Provider). And I am hopeful that I meet my Lord and none of you are seeking (recompense from) me for an injustice involving blood or wealth}}
\hadithdefcmd{ibnmajah}{2201}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ غَلاَ السِّعْرُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالُوا لَوْ قَوَّمْتَ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ إِنِّي لأَرْجُو أَنْ أُفَارِقَكُمْ وَلاَ يَطْلُبَنِي أَحَدٌ مِنْكُمْ بِمَظْلَمَةٍ ظَلَمْتُهُ ‏"‏ ‏.‏\hadithno{2201}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:"Prices rose at the time of the Messenger of Allah (ﷺ), and they said: 'Why do you not fix the food prices, O Messenger of Allah?' He said: 'I hope that when I leave you, no one among you will be demanding restitution for a wrong that I have done to him}}
\hadithdefcmd{ibnmajah}{2202}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبَانَ الْبَلْخِيُّ أَبُو بَكْرٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ عَطَاءِ بْنِ فَرُّوخَ، قَالَ قَالَ عُثْمَانُ بْنُ عَفَّانَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَدْخَلَ اللَّهُ رَجُلاً الْجَنَّةَ كَانَ سَهْلاً بَائِعًا وَمُشْتَرِيًا ‏"‏ ‏.‏\hadithno{2202}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Uthman bin 'Affan narrated that the Messenger of Allah (ﷺ) said:“Allah will admit to Paradise a man who was lenient when he sold and when he bought}}
\hadithdefcmd{ibnmajah}{2203}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ مُطَرِّفٍ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رَحِمَ اللَّهُ عَبْدًا سَمْحًا إِذَا بَاعَ سَمْحًا إِذَا اشْتَرَى سَمْحًا إِذَا اقْتَضَى ‏"‏ ‏.‏\hadithno{2203}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:"May Allah have mercy on a person who is lenient when he sells, lenient when he buys, and lenient when he asks for payment}}
\hadithdefcmd{ibnmajah}{2204}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا يَعْلَى بْنُ شَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ قَيْلَةَ أُمِّ بَنِي أَنْمَارٍ، قَالَتْ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي بَعْضِ عُمَرِهِ عِنْدَ الْمَرْوَةِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ أَبِيعُ وَأَشْتَرِي فَإِذَا أَرَدْتُ أَنْ أَبْتَاعَ الشَّىْءَ سُمْتُ بِهِ أَقَلَّ مِمَّا أُرِيدُ ثُمَّ زِدْتُ ثُمَّ زِدْتُ حَتَّى أَبْلُغَ الَّذِي أُرِيدُ وَإِذَا أَرَدْتُ أَنْ أَبِيعَ الشَّىْءَ سُمْتُ بِهِ أَكْثَرَ مِنَ الَّذِي أُرِيدُ ثُمَّ وَضَعْتُ حَتَّى أَبْلُغَ الَّذِي أُرِيدُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ تَفْعَلِي يَا قَيْلَةُ إِذَا أَرَدْتِ أَنْ تَبْتَاعِي شَيْئًا فَاسْتَامِي بِهِ الَّذِي تُرِيدِينَ أُعْطِيتِ أَوْ مُنِعْتِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِذَا أَرَدْتِ أَنْ تَبِيعِي شَيْئًا فَاسْتَامِي بِهِ الَّذِي تُرِيدِينَ أَعْطَيْتِ أَوْ مَنَعْتِ ‏"‏ ‏.‏\hadithno{2204}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qailah Umm Bani Anmar said:"I came to the Messenger of Allah (ﷺ), during one of his 'Umrah at Marwah and said: 'O Messenger of Allah, I am a woman who buys and sells. When I want to buy something, I state a price less than I want to pay, then I raise it gradually until it reaches the price I want to pay. And when I want to sell something, I state a price more than I want, then I lower it until it reaches the price I want.' The Messenger of Allah (ﷺ) said: 'Do not do that, O Qailah. When you want to buy something, state the price you want, whether it is given or not. And when you want to sell something, state the price you want, whether it is given or not}}
\hadithdefcmd{ibnmajah}{2205}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي غَزْوَةٍ فَقَالَ لِي ‏"‏ أَتَبِيعُ نَاضِحَكَ هَذَا بِدِينَارٍ وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ هُوَ نَاضِحُكُمْ إِذَا أَتَيْتُ الْمَدِينَةَ ‏.‏ قَالَ ‏"‏ فَتَبِيعُهُ بِدِينَارَيْنِ وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قَالَ فَمَا زَالَ يَزِيدُنِي دِينَارًا دِينَارًا وَيَقُولُ مَكَانَ كُلِّ دِينَارٍ ‏"‏ وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ حَتَّى بَلَغَ عِشْرِينَ دِينَارًا فَلَمَّا أَتَيْتُ الْمَدِينَةَ أَخَذْتُ بِرَأْسِ النَّاضِحِ فَأَتَيْتُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا بِلاَلُ أَعْطِهِ مِنَ الْعَيْبَةِ عِشْرِينَ دِينَارًا ‏"‏ ‏.‏ وَقَالَ ‏"‏ انْطَلِقْ بِنَاضِحِكَ وَاذْهَبْ بِهِ إِلَى أَهْلِكَ ‏"‏ ‏.‏\hadithno{2205}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"I was with the Prophet (ﷺ) on a military campaign, and he said to me: 'Will you sell this camel of yours for a Dinar?' I said: 'O Messenger of Allah, it is yours when I get to Al-Madinah.' He said: 'Then sell it for two Dinar, may Allah forgive you.' And he kept increasing the price for me, saying: 'May Allah forgive you,' each time, until the amount reached twenty Dinar. When I came to Al-Madinah, I took hold of the camel's head and brought it to the Prophet (ﷺ) and he said: 'O Bilal, give him twenty Dinar from the spoils of war.' And he said: 'Take your camel away and go to your people with it}}
\hadithdefcmd{ibnmajah}{2206}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا الرَّبِيعُ بْنُ حَبِيبٍ، عَنْ نَوْفَلِ بْنِ عَبْدِ الْمَلِكِ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ السَّوْمِ قَبْلَ طُلُوعِ الشَّمْسِ وَعَنْ ذَبْحِ ذَوَاتِ الدَّرِّ ‏.‏\hadithno{2206}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) forbade haggling before sunrise, and (he forbade) slaughtering animals that yield milk}}
\hadithdefcmd{ibnmajah}{2207}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ عَلَى فَضْلِ مَاءٍ بِالْفَلاَةِ يَمْنَعُهُ ابْنَ السَّبِيلِ وَرَجُلٌ بَايَعَ رَجُلاً سِلْعَةً بَعْدَ الْعَصْرِ فَحَلَفَ بِاللَّهِ لأَخَذَهَا بِكَذَا وَكَذَا فَصَدَّقَهُ وَهُوَ عَلَى غَيْرِ ذَلِكَ وَرَجُلٌ بَايَعَ إِمَامًا لاَ يُبَايِعُهُ إِلاَّ لِدُنْيَا فَإِنْ أَعْطَاهُ مِنْهَا وَفَى لَهُ وَإِنْ لَمْ يُعْطِهِ مِنْهَا لَمْ يَفِ لَهُ ‏"‏ ‏.‏\hadithno{2207}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"There are three to whom Allah will not speak on the Day of Resurrection, nor will He look at them or purify them, and theirs will be a painful torment: A man who has surplus water in the desert but refuses to give any to a wayfarer; a man who sells a product to a man after 'Asr and swears by Allah that he bought it for such and such amount, and he believes him, when that is not the case; and a man who swears allegiance to a ruler, and only does so for worldly gains, so if he gives him some of (these worldly benefits) he fulfills his oath of allegiance, and if he is not given anything he does not uphold his oath of allegiance}}
\hadithdefcmd{ibnmajah}{2208}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الْمَسْعُودِيِّ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ فَقُلْتُ مَنْ هُمْ يَا رَسُولَ اللَّهِ فَقَدْ خَابُوا وَخَسِرُوا ‏.‏ قَالَ ‏"‏ الْمُسْبِلُ إِزَارَهُ وَالْمَنَّانُ عَطَاءَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ ‏"‏ ‏.‏\hadithno{2208}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that the Prophet (ﷺ) said:"There are three to whom Allah will not speak on the Day of Resurrection nor will He look at them or purify them, and theirs will be a painful torment." I said: "Who are they, O Messenger of Allah? For they are indeed losers." He said: "The one who lets his garment hang beneath his ankles, the one who reminds another of what he has given him, and the one who sells his product by means of false oaths}}
\hadithdefcmd{ibnmajah}{2209}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِيَّاكُمْ وَالْحَلِفَ فِي الْبَيْعِ فَإِنَّهُ يُنَفِّقُ ثُمَّ يَمْحَقُ ‏"‏ ‏.‏\hadithno{2209}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ), said:"Beware of swearing oaths when selling, for it may help you to make a sale but it destroys the blessing}}
\hadithdefcmd{ibnmajah}{2210}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ اشْتَرَى نَخْلاً قَدْ أُبِّرَتْ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{2210}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Whoever buys a palm tree that has been pollinated, its fruits belong to the seller, unless the purchaser stipulated a condition." (Sahih) Another chain from Ibn 'Umar, from the Prophet (ﷺ), with similar wording}}
\hadithdefcmd{ibnmajah}{2211}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، جَمِيعًا عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ بَاعَ نَخْلاً قَدْ أُبِّرَتْ فَثَمَرَتُهَا لِلَّذِي بَاعَهَا إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَمَنِ ابْتَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلَّذِي بَاعَهُ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{2211}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim bin 'Abdullah, bin 'Umar, from Ibn 'Umar, that :the Messenger of Allah (ﷺ) said: "Whoever sells a palm tree that has been pollinated, its fruits belong to the seller, unless the purchaser stipulated a condition. And whoever buys a slave who has wealth, his wealth belongs to the seller, unless the purchaser stipulated a condition}}
\hadithdefcmd{ibnmajah}{2212}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ مَنْ بَاعَ نَخْلاً وَبَاعَ عَبْدًا جَمَعَهُمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{2212}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Nafi' from Ibn 'Umar that the Prophet (ﷺ) said:"Whoever sells a palm tree and sells a slave." Mentioning both of them together}}
\hadithdefcmd{ibnmajah}{2213}{حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ خَالِدٍ النُّمَيْرِيُّ أَبُو الْمُغَلِّسِ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، عَنْ مُوسَى بْنِ عُقْبَةَ، حَدَّثَنِي إِسْحَاقُ بْنُ يَحْيَى بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَضَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّ ثَمَرَ النَّخْلِ لِمَنْ أَبَّرَهَا إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَأَنَّ مَالَ الْمَمْلُوكِ لِمَنْ بَاعَهُ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏.‏\hadithno{2213}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ubadah bin Samit said:"The Messenger of Allah (ﷺ) ruled that the fruit of a palm tree belongs to the one who pollinated it, and that the wealth of a slave belongs to the one who sold him, unless the purchaser stipulated a condition}}
\hadithdefcmd{ibnmajah}{2214}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَةَ حَتَّى يَبْدُوَ صَلاَحُهَا ‏"‏ ‏.‏ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{2214}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Do not sell fruits until they have ripened." And he forbade (both) the seller and the purchaser (to engage in such a transaction)}}
\hadithdefcmd{ibnmajah}{2215}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏.‏\hadithno{2215}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Do not sell fruits until they have ripened}}
\hadithdefcmd{ibnmajah}{2216}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ ‏.‏\hadithno{2216}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir that :the Prophet (ﷺ) forbade selling fruits until they have ripened}}
\hadithdefcmd{ibnmajah}{2217}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ الثَّمَرَةِ حَتَّى تَزْهُوَ وَعَنْ بَيْعِ الْعِنَبِ حَتَّى يَسْوَدَّ وَعَنْ بَيْعِ الْحَبِّ حَتَّى يَشْتَدَّ ‏.‏\hadithno{2217}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that :the Messenger of Allah (ﷺ) forbade selling fruits until they have changed the color, and selling grapes until they have turned black, and selling grains until they have hardened}}
\hadithdefcmd{ibnmajah}{2218}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ بْنِ عَتِيقٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ السِّنِينَ ‏.‏\hadithno{2218}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin 'Abdullah that :the Messenger of Allah (ﷺ) forbade selling for many years ahead}}
\hadithdefcmd{ibnmajah}{2219}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ بَاعَ ثَمَرًا فَأَصَابَتْهُ جَائِحَةٌ فَلاَ يَأْخُذْ مِنْ مَالِ أَخِيهِ شَيْئًا عَلاَمَ يَأْخُذُ أَحَدُكُمْ مَالَ أَخِيهِ الْمُسْلِمِ ‏"‏ ‏.‏\hadithno{2219}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:"Whoever sells fruits then the crop fails, should not take any of his brother's money. Why would any of you take the money of his Muslim brother?}}
\hadithdefcmd{ibnmajah}{2220}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، قَالَ جَلَبْتُ أَنَا وَمَخْرَفَةُ الْعَبْدِيُّ، بَزًّا مِنْ هَجَرَ فَجَاءَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَاوَمَنَا سَرَاوِيلَ وَعِنْدَنَا وَزَّانٌ يَزِنُ بِالأَجْرِ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا وَزَّانُ زِنْ وَأَرْجِحْ ‏"‏ ‏.‏\hadithno{2220}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suwaid bin Qais said:"Makhrafah Al' Abdi and I brought linens from Hajar[1] The Messenger of Allah (ﷺ) came to us to bargain with us with some trousers. There was someone with me who weighed (the goods) in exchange for a wage. So the Prophet (ﷺ) said to the one weighing: 'Weigh and add more}}
\hadithdefcmd{ibnmajah}{2221}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ مَالِكًا أَبَا صَفْوَانَ بْنَ عُمَيْرَةَ، قَالَ بِعْتُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رِجْلَ سَرَاوِيلَ قَبْلَ الْهِجْرَةِ فَوَزَنَ لِي فَأَرْجَحَ لِي ‏.‏\hadithno{2221}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Simak bin Harb said:"I heard Malik Abu Safwan bin 'Umairah, say: 'I bought a pair of trousers from the Messenger of Allah (ﷺ) before the Hijrah, and he weighed it for me and allowed more}}
\hadithdefcmd{ibnmajah}{2222}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وَزَنْتُمْ فَأَرْجِحُوا ‏"‏ ‏.‏\hadithno{2222}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:"When you weigh, allow more}}
\hadithdefcmd{ibnmajah}{2223}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرِ بْنِ الْحَكَمِ، وَمُحَمَّدُ بْنُ عَقِيلِ بْنِ خُوَيْلِدٍ، قَالاَ حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، حَدَّثَنِي أَبِي، حَدَّثَنِي يَزِيدُ النَّحْوِيُّ، أَنَّ عِكْرِمَةَ، حَدَّثَهُ عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ كَانُوا مِنْ أَخْبَثِ النَّاسِ كَيْلاً فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{وَيْلٌ لِلْمُطَفِّفِينَ\}‏ فَأَحْسَنُوا الْكَيْلَ بَعْدَ ذَلِكَ ‏.‏\hadithno{2223}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"When the Prophet (ﷺ) came to Al-Madinah, they were the worst people in weights and measures. Then Allah, Glorious is He revealed: "Woe to the Mutaffifun (those who give less in measure and weight)",[1] and they were fair in weights and measures after that}}
\hadithdefcmd{ibnmajah}{2224}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِرَجُلٍ يَبِيِعُ طَعَامًا فَأَدْخَلَ يَدَهُ فِيهِ فَإِذَا هُوَ مَغْشُوشٌ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ مِنَّا مَنْ غَشَّ ‏"‏ ‏.‏\hadithno{2224}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) passed by a man who was selling food. He put his hand in it and saw that there was something wrong with it. The Messenger of Allah (ﷺ) said, 'He is not one of us who cheats}}
\hadithdefcmd{ibnmajah}{2225}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي دَاوُدَ، عَنْ أَبِي الْحَمْرَاءِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِجَنَبَاتِ رَجُلٍ عِنْدَهُ طَعَامٌ فِي وِعَاءٍ فَأَدْخَلَ يَدَهُ فِيهِ فَقَالَ ‏ "‏ لَعَلَّكَ غَشَشْتَهُ مَنْ غَشَّنَا فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{2225}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hamra' said:"I saw the Messenger of Allah (ﷺ) pass by a man having food in a vessel. He put his hand in it and said: 'Perhaps you are cheating. Whoever cheats us is not one of us}}
\hadithdefcmd{ibnmajah}{2226}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{2226}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) said:"Whoever buys food, let him not sell it until he has taken full possession of it}}
\hadithdefcmd{ibnmajah}{2227}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا أَبُو عَوَانَةَ، وَحَمَّادُ بْنُ زَيْدٍ، قَالاَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏ قَالَ أَبُو عَوَانَةَ فِي حَدِيثِهِ قَالَ ابْنُ عَبَّاسٍ وَأَحْسِبُ كُلَّ شَىْءٍ مِثْلَ الطَّعَامِ ‏.‏\hadithno{2227}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) said: 'Whoever buys food, let him not sell it until he has taken full possession of it.'" (Sahih) In his narration, (one of the narrators) Abu 'Awanah said: "Ibn 'Abbas said: 'I think everything is like food}}
\hadithdefcmd{ibnmajah}{2228}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعِ الطَّعَامِ حَتَّى يَجْرِيَ فِيهِ الصَّاعَانِ صَاعُ الْبَائِعِ وَصَاعُ الْمُشْتَرِي ‏.‏\hadithno{2228}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:'The Messenger of Allah (ﷺ) forbade selling food bought by measure until two Sa' have been measured - the Sa' of the seller and the Sa' of the buyer}}
\hadithdefcmd{ibnmajah}{2229}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَشْتَرِي الطَّعَامَ مِنَ الرُّكْبَانِ جِزَافًا فَنَهَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَبِيعَهُ حَتَّى نَنْقُلَهُ مِنْ مَكَانِهِ ‏.‏\hadithno{2229}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"We used to buy food from troops of riders (i.e., the caravans) without knowing the amount, but the Messenger of Allah (ﷺ) forbade us to sell it until it had been delivered to us}}
\hadithdefcmd{ibnmajah}{2230}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، عَنِ ابْنِ لَهِيعَةَ، عَنْ مُوسَى بْنِ وَرْدَانَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ كُنْتُ أَبِيعُ التَّمْرَ فِي السُّوقِ فَأَقُولُ كِلْتُ فِي وَسْقِي هَذَا كَذَا ‏.‏ فَأَدْفَعُ أَوْسَاقَ التَّمْرِ بِكَيْلِهِ وَآخُذُ شِفِّي فَدَخَلَنِي مِنْ ذَلِكَ شَىْءٌ فَسَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِذَا سَمَّيْتَ الْكَيْلَ فَكِلْهُ ‏"‏ ‏.‏\hadithno{2230}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"I used to sell dates in the marketplace, and I would say: 'This was such and such an amount (when I bought it).' I Would give the purchaser a specific amount of dates according to the way it had been measured for me, and take my profit. Then I began to have some doubts about that, so I asked the Messenger of Allah (ﷺ), and he said: ‘When you name the amount, measure it in front of the purchaser}}
\hadithdefcmd{ibnmajah}{2231}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الْيَحْصُبِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ الْمَازِنِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ كِيلُوا طَعَامَكُمْ يُبَارَكْ لَكُمْ فِيهِ ‏"‏ ‏.‏\hadithno{2231}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abdullah bin Busr Al-Mazini said:"I heard the Messenger of Allah (ﷺ) say: 'Measure your food, may you be blessed therein}}
\hadithdefcmd{ibnmajah}{2232}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كِيلُوا طَعَامَكُمْ يُبَارَكْ لَكُمْ فِيهِ ‏"‏ ‏.‏\hadithno{2232}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Ayyub that the Prophet (ﷺ) said:"Measure your food, may you be blessed therein}}
\hadithdefcmd{ibnmajah}{2233}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ سَعِيدٍ، حَدَّثَنِي صَفْوَانُ بْنُ سُلَيْمٍ، حَدَّثَنِي مُحَمَّدٌ، وَعَلِيٌّ، ابْنَا الْحَسَنِ بْنِ أَبِي الْحَسَنِ الْبَرَّادِ أَنَّ الزُّبَيْرَ بْنَ الْمُنْذِرِ بْنِ أَبِي أُسَيْدٍ السَّاعِدِيِّ، حَدَّثَهُمَا أَنَّ أَبَاهُ الْمُنْذِرَ حَدَّثَهُ عَنْ أَبِي أُسَيْدٍ، أَنَّ أَبَا أُسَيْدٍ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ذَهَبَ إِلَى سُوقِ النَّبِيطِ فَنَظَرَ إِلَيْهِ فَقَالَ ‏"‏ لَيْسَ هَذَا لَكُمْ بِسُوقٍ ‏"‏ ‏.‏ ثُمَّ ذَهَبَ إِلَى سُوقٍ فَنَظَرَ إِلَيْهِ فَقَالَ ‏"‏ لَيْسَ هَذَا لَكُمْ بِسُوقٍ ‏"‏ ‏.‏ ثُمَّ رَجَعَ إِلَى هَذَا السُّوقِ فَطَافَ فِيهِ ثُمَّ قَالَ ‏"‏ هَذَا سُوقُكُمْ فَلاَ يُنْتَقَصَنَّ وَلاَ يُضْرَبَنَّ عَلَيْهِ خَرَاجٌ ‏"‏ ‏.‏\hadithno{2233}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Usaid said that :the Messenger of Allah (ﷺ) went to the market of Nabit,[1] and looked at it, and said: "This is not a market for you." Then we went to another market and looked at it, and said: "This is not a market for you." Then he came back to this market and walked around in it then he said: "This is your market. It will always be your market and no duty will be levied on it." (Do,if)}}
\hadithdefcmd{ibnmajah}{2234}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ الْعُرُوقِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْسُ بْنُ مَيْمُونٍ، حَدَّثَنَا عَوْنٌ الْعُقَيْلِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ غَدَا إِلَى صَلاَةِ الصُّبْحِ غَدَا بِرَايَةِ الإِيمَانِ وَمَنْ غَدَا إِلَى السُّوقِ غَدَا بِرَايَةِ إِبْلِيسَ ‏"‏ ‏.‏\hadithno{2234}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salman said :"I heard the Messenger of Allah (ﷺ) saying: 'Whoever goes to the Morning prayer first thing in the morning, he goes out with the banner of faith but whoever goes out to the marketplace first thing in the morning, he goes out under the banner of Iblis (Satan)}}
\hadithdefcmd{ibnmajah}{2235}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الضَّرِيرُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، مَوْلَى آلِ الزُّبَيْرِ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَالَ حِينَ يَدْخُلُ السُّوقَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ حَىٌّ لاَ يَمُوتُ بِيَدِهِ الْخَيْرُ كُلُّهُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ - كَتَبَ اللَّهُ لَهُ أَلْفَ أَلْفِ حَسَنَةٍ وَمَحَا عَنْهُ أَلْفَ أَلْفِ سَيِّئَةٍ وَبَنَى لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2235}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim bin 'Abdullah bin 'Umar, from his father, that his grandfather told that the Messenger of Allah (ﷺ) said:"Whoever says, when he enters the marketplace: 'La ilaha illallah wahdahu la sharika lahu, lahul-mulk wa lahul-hamdu, yuhyi wa yumitu, wa Huwa hayyun la yamutu, bi yadihil-khairu kulluhu, wa Huwa ala kulli shay’in Qadir (None has the right to be worshiped but Allah alone, with no partner, to Him belongs all sovereignty and to Him is the praise, He gives life and gives death, and He is Ever-Living and does not die; in His Hand is all goodness and He is Able to do all things),' Allah will record for him one million good deeds, and will erase from him one million bad deeds, and will build for him a house in Paradise}}
\hadithdefcmd{ibnmajah}{2236}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ عُمَارَةَ بْنِ حَدِيدٍ، عَنْ صَخْرٍ الْغَامِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ بَارِكْ لأُمَّتِي فِي بُكُورِهَا ‏"‏ ‏.‏ قَالَ وَكَانَ إِذَا بَعَثَ سَرِيَّةً أَوْ جَيْشًا بَعَثَهُمْ فِي أَوَّلِ النَّهَارِ ‏.‏ قَالَ وَكَانَ صَخْرٌ رَجُلاً تَاجِرًا فَكَانَ يَبْعَثُ تِجَارَتَهُ فِي أَوَّلِ النَّهَارِ فَأَثْرَى وَكَثُرَ مَالُهُ ‏.‏\hadithno{2236}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Sakhr Al-Ghamidi that the Messenger of Allah (ﷺ) said:"O Allah, bless my nation in their early mornings (i.e., what they do early in the morning)." (Hasan)He said: "When he sent out a raiding party or an army, he would send them at the beginning of the day." He said: (1) "Sakhr was a man engaged in trade, and he used to send his goods out at the beginning of the day, and his wealth grew and increased}}
\hadithdefcmd{ibnmajah}{2237}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ مَيْمُونٍ الْمَدَنِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّهُمَّ بَارِكْ لأُمَّتِي فِي بُكُورِهَا يَوْمَ الْخَمِيسِ ‏"‏ ‏.‏\hadithno{2237}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"O Allah, bless my nation early in the morning of Thursday}}
\hadithdefcmd{ibnmajah}{2238}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا إِسْحَاقُ بْنُ جَعْفَرِ بْنِ مُحَمَّدِ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الْجُدْعَانِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لأُمَّتِي فِي بُكُورِهَا ‏"‏ ‏.‏\hadithno{2238}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah (ﷺ) said:"O Allah, bless my nation early in the morning}}
\hadithdefcmd{ibnmajah}{2239}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ ابْتَاعَ مُصَرَّاةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ فَإِنْ رَدَّهَا رَدَّ مَعَهَا صَاعًا مِنْ تَمْرٍ لاَ سَمْرَاءَ ‏"‏ ‏.‏ يَعْنِي الْحِنْطَةَ ‏.‏\hadithno{2239}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) said:"O Allah, bless my nation in their early mornings.". It was narrated from Abu Hurairah that the Prophet (ﷺ) said: "Whoever buys a Musarrah, he has the choice (of annulling the deal) for three days. If he returns it, then he must also give a Sa' of dates, not Samra'." Meaning wheat}}
\hadithdefcmd{ibnmajah}{2240}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا صَدَقَةُ بْنُ سَعِيدٍ الْحَنَفِيُّ، حَدَّثَنَا جُمَيْعُ بْنُ عُمَيْرٍ التَّيْمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا أَيُّهَا النَّاسُ مَنْ بَاعَ مُحَفَّلَةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ فَإِنْ رَدَّهَا رَدَّ مَعَهَا مِثْلَىْ لَبَنِهَا - أَوْ قَالَ مِثْلَ لَبَنِهَا - قَمْحًا ‏"‏ ‏.‏\hadithno{2240}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin 'Umar said:"The Messenger of Allah (ﷺ) said: 'Whoever buys a Muhaffalah, (1) he has the choice (of annulling the deal) for three days. If he returns it, then he must also give wheat equal to twice, the amount of its milk, or equal to the amount of its milk}}
\hadithdefcmd{ibnmajah}{2241}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ جَابِرٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّهُ قَالَ أَشْهَدُ عَلَى الصَّادِقِ الْمَصْدُوقِ أَبِي الْقَاسِمِ ـ صلى الله عليه وسلم ـ أَنَّهُ حَدَّثَنَا قَالَ ‏ "‏ بَيْعُ الْمُحَفَّلاَتِ خِلاَبَةٌ وَلاَ تَحِلُّ الْخِلاَبَةُ لِمُسْلِمٍ ‏"‏ ‏.‏\hadithno{2241}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"I bear witness that the true and truly inspired one Abul-Qasim (ﷺ) told us: 'Selling a Muhaffalah is Khilabah, and Khilabah is not lawful for the Muslim."' (Ibn Majah said: " Meaning: 'Deception)}}
\hadithdefcmd{ibnmajah}{2242}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ مَخْلَدِ بْنِ خُفَافِ بْنِ إِيمَاءَ بْنِ رَحَضَةَ الْغِفَارِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَضَى أَنَّ خَرَاجَ الْعَبْدِ بِضَمَانِهِ ‏.‏\hadithno{2242}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Aishah that :the Messenger of Allah (ﷺ) ruled that what a slave earns belongs to his guarantor}}
\hadithdefcmd{ibnmajah}{2243}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ الزَّنْجِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، اشْتَرَى عَبْدًا فَاسْتَغَلَّهُ ثُمَّ وَجَدَ بِهِ عَيْبًا فَرَدَّهُ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ قَدِ اسْتَغَلَّ غُلاَمِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْخَرَاجُ بِالضَّمَانِ ‏"‏ ‏.‏\hadithno{2243}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that:a man bought a slave and put him to work, then he found some defect in him, so he returned him. He (the seller) said: "O Messenger of Allah he put my slave to work." The Messenger of Allah (ﷺ) said: "A slave's earnings belong to his guarantor}}
\hadithdefcmd{ibnmajah}{2244}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، إِنْ شَاءَ اللَّهُ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ عُهْدَةُ الرَّقِيقِ ثَلاَثَةُ أَيَّامٍ ‏"‏ ‏.‏\hadithno{2244}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundab that the Messenger of Allah (ﷺ) said:"The contractual obligation regarding a slave lasts for three days}}
\hadithdefcmd{ibnmajah}{2245}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ عُهْدَةَ بَعْدَ أَرْبَعٍ ‏"‏ ‏.‏\hadithno{2245}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that the Messenger of Allah (ﷺ) said:"There is no contractual obligation after four (days)}}
\hadithdefcmd{ibnmajah}{2246}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ وَلاَ يَحِلُّ لِمُسْلِمٍ بَاعَ مِنْ أَخِيهِ بَيْعًا فِيهِ عَيْبٌ إِلاَّ بَيَّنَهُ لَهُ ‏"‏ ‏.‏\hadithno{2246}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"I heard the Messenger of Allah (ﷺ) say: 'The Muslim is the brother of another Muslim, and it is not permissible for a Muslim to sell his brother goods in which there is a defect, without pointing that out to him}}
\hadithdefcmd{ibnmajah}{2247}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ الضَّحَّاكِ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ مُعَاوِيَةَ بْنِ يَحْيَى، عَنْ مَكْحُولٍ، وَسُلَيْمَانَ بْنِ مُوسَى، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ بَاعَ عَيْبًا لَمْ يُبَيِّنْهُ لَمْ يَزَلْ فِي مَقْتٍ مِنَ اللَّهِ وَلَمْ تَزَلِ الْمَلاَئِكَةُ تَلْعَنُهُ ‏"‏ ‏.‏\hadithno{2247}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Wathilah bin Asqa' said:"I heard the Messenger of Allah (ﷺ) say: 'Whoever sells defective goods without pointing it out, he will remain subject to the wrath of Allah, and the angels will continue to curse him}}
\hadithdefcmd{ibnmajah}{2248}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ جَابِرٍ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا أُتِيَ بِالسَّبْىِ أَعْطَى أَهْلَ الْبَيْتِ جَمِيعًا كَرَاهِيَةَ أَنْ يُفَرِّقَ بَيْنَهُمْ ‏.‏\hadithno{2248}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"When captives were brought to him, the Prophet (ﷺ) would give the members of one family together (to one person), not wanting to separate them}}
\hadithdefcmd{ibnmajah}{2249}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَفَّانُ، عَنْ حَمَّادٍ، أَنْبَأَنَا الْحَجَّاجُ، عَنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ عَلِيٍّ، قَالَ وَهَبَ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ غُلاَمَيْنِ أَخَوَيْنِ فَبِعْتُ أَحَدَهُمَا فَقَالَ ‏"‏ مَا فَعَلَ الْغُلاَمَانِ ‏"‏ ‏.‏ قُلْتُ بِعْتُ أَحَدَهُمَا قَالَ ‏"‏ رُدَّهُ ‏"‏ ‏.‏\hadithno{2249}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ) gave me two slaves who were brothers, and I sold one of them. He said: 'What happened with the two slaves?' I said: 'I sold one of them.' He said: 'Take him back}}
\hadithdefcmd{ibnmajah}{2250}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْهَيَّاجِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا إِبْرَاهِيمُ بْنُ إِسْمَاعِيلَ، عَنْ طَلِيقِ بْنِ عِمْرَانَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَنْ فَرَّقَ بَيْنَ الْوَالِدَةِ وَوَلَدِهَا وَبَيْنَ الأَخِ وَبَيْنَ أَخِيهِ ‏.‏\hadithno{2250}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa said:"The Messenger of Allah (ﷺ) cursed the one who separates a mother and her child, or a brother from his brother}}
\hadithdefcmd{ibnmajah}{2251}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبَّادُ بْنُ لَيْثٍ، صَاحِبُ الْكَرَابِيسِيِّ حَدَّثَنَا عَبْدُ الْمَجِيدِ بْنُ وَهْبٍ، قَالَ قَالَ لِي الْعَدَّاءُ بْنُ خَالِدِ بْنِ هَوْذَةَ أَلاَ نُقْرِئُكَ كِتَابًا كَتَبَهُ لِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ قُلْتُ بَلَى ‏.‏ فَأَخْرَجَ لِي كِتَابًا فَإِذَا فِيهِ ‏ "‏ هَذَا مَا اشْتَرَى الْعَدَّاءُ بْنُ خَالِدِ بْنِ هَوْذَةَ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ اشْتَرَى مِنْهُ عَبْدًا أَوْ أَمَةً لاَ دَاءَ وَلاَ غَائِلَةَ وَلاَ خِبْثَةَ بَيْعَ الْمُسْلِمِ لِلْمُسْلِمِ ‏"‏ ‏.‏\hadithno{2251}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdul-Majid bin Wahb said:"Adda' bin Khalid bin Hawdhah said to me: 'Shall I not read to you a letter that the Messenger of Allah (ﷺ), wrote to me?' I said: 'Yes.' So he took out a letter. In it was: 'This is what 'Adda' bin Khalid bin Hawdhah bought [from] Muhammad the Messenger of Allah (ﷺ) He bought from him a slave' or 'a female slave, having no ailments, nor being a runaway, not having any malicious behavior. Sold by a Muslim to a Muslim}}
\hadithdefcmd{ibnmajah}{2252}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اشْتَرَى أَحَدُكُمُ الْجَارِيَةَ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ خَيْرَهَا وَخَيْرَ مَا جَبَلْتَهَا عَلَيْهِ وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَشَرِّ مَا جَبَلْتَهَا عَلَيْهِ وَلْيَدْعُ بِالْبَرَكَةِ وَإِذَا اشْتَرَى أَحَدُكُمْ بَعِيرًا فَلْيَأْخُذْ بِذِرْوَةِ سَنَامِهِ وَلْيَدْعُ بِالْبَرَكَةِ وَلْيَقُلْ مِثْلَ ذَلِكَ ‏"‏ ‏.‏\hadithno{2252}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father that his grandfather told that the Messenger of Allah (ﷺ) said:"When anyone of you buys a slave woman let him say: 'Allahumma inni as'aluka khairaha wa khaira ma jabaltaha alaihi, wa a'udhu bika min sharriha wa sharri ma jabaltaha alaihi (O Allah, I ask You for the goodness within her and the goodness that You have made her inclined towards, and I seek refuge with You from the evil within her and the evil that You have made her inclined towards).' And he should pray for blessing. And if anyone of you buys a camel then he should take hold of its hump and pray for. blessing and say similar words}}
\hadithdefcmd{ibnmajah}{2253}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَهِشَامُ بْنُ عَمَّارٍ، وَنَصْرُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ النَّصْرِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الذَّهَبُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏ ‏.‏\hadithno{2253}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Malik bin Aws bin Hadathan Nasri said:"I heard 'Umar bin Al-Khattab say: 'The Messenger of Allah (ﷺ) said: "Exchanging gold for gold is usury unless it is done on the spot. (Exchanging) wheat for wheat is usury, unless it is done on the spot. (Exchanging) barley for barley is usury unless it is done on the spot. (Exchanging) dates for dates is usury, unless it is done on the spot}}
\hadithdefcmd{ibnmajah}{2254}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خِدَاشٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، قَالاَ حَدَّثَنَا سَلَمَةُ بْنُ عَلْقَمَةَ التَّمِيمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، أَنَّ مُسْلِمَ بْنَ يَسَارٍ، وَعَبْدَ اللَّهِ بْنَ عُبَيْدٍ، حَدَّثَاهُ قَالاَ، جَمَعَ الْمَنْزِلُ بَيْنَ عُبَادَةَ بْنِ الصَّامِتِ وَمُعَاوِيَةَ إِمَّا فِي كَنِيسَةٍ وَإِمَّا فِي بِيعَةٍ فَحَدَّثَهُمْ عُبَادَةُ بْنُ الصَّامِتِ فَقَالَ نَهَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ بَيْعِ الْوَرِقِ بِالْوَرِقِ وَالذَّهَبِ بِالذَّهَبِ وَالْبُرِّ بِالْبُرِّ وَالشَّعِيرِ بِالشَّعِيرِ وَالتَّمْرِ بِالتَّمْرِ - قَالَ أَحَدُهُمَا وَالْمِلْحِ بِالْمِلْحِ وَلَمْ يَقُلْهُ الآخَرُ - وَأَمَرَنَا أَنْ نَبِيعَ الْبُرَّ بِالشَّعِيرِ وَالشَّعِيرَ بِالْبُرِّ يَدًا بِيَدٍ كَيْفَ شِئْنَا ‏.‏\hadithno{2254}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muslim bin Yasar and 'Abdullah bin 'Ubaid said :"Ubadah bin Samit and Mu'awiyah happened to meet, either in a church or in a synagogue. 'Ubadah bin Samit narrated to them and said: 'The Messenger of Allah (ﷺ) forbade us from selling silver for silver, gold for gold, wheat for wheat, barley for barley, and dates for dates.'I one of them said: "And salt for salt," but the other did not say it. "And he commanded us to sell wheat for barley, or barley for wheat, hand-to-hand, however we wished}}
\hadithdefcmd{ibnmajah}{2255}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا فُضَيْلُ بْنُ غَزْوَانَ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْفِضَّةُ بِالْفِضَّةِ وَالذَّهَبُ بِالذَّهَبِ وَالشَّعِيرُ بِالشَّعِيرِ وَالْحِنْطَةُ بِالْحِنْطَةِ مِثْلاً بِمِثْلٍ ‏"‏ ‏.‏\hadithno{2255}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:'(Sell) silver for silver, gold for gold, barley for barley, wheat for wheat, like for like}}
\hadithdefcmd{ibnmajah}{2256}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَرْزُقُنَا تَمْرًا مِنْ تَمْرِ الْجَمْعِ فَنَسْتَبْدِلُ بِهِ تَمْرًا هُوَ أَطْيَبُ مِنْهُ وَنَزِيدُ فِي السِّعْرِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَصْلُحُ صَاعُ تَمْرٍ بِصَاعَيْنِ وَلاَ دِرْهَمٌ بِدِرْهَمَيْنِ وَالدِّرْهَمُ بِالدِّرْهَمِ وَالدِّينَارُ بِالدِّينَارِ لاَ فَضْلَ بَيْنَهُمَا إِلاَّ وَزْنًا ‏"‏ ‏.‏\hadithno{2256}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Sa’eed said:“The Prophet used to give us dates from the collection (mixed) [1] dates, and we would exchange them for dates that were better, and we add to the price. [2] The Messenger of Allah said: ‘It is not right to give one Sa of dates for two Sa, nor one Dirham for two Dirham. A Dirham for a Dirham and a Dinar for a Dinar is allowed: the only difference between them is in weight (i.e., the weight must be equal.)’” Sahih}}
\hadithdefcmd{ibnmajah}{2257}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ الدِّرْهَمُ بِالدِّرْهَمِ وَالدِّينَارُ بِالدِّينَارِ ‏.‏ فَقُلْتُ إِنِّي سَمِعْتُ ابْنَ عَبَّاسٍ يَقُولُ غَيْرَ ذَلِكَ ‏.‏ قَالَ أَمَا إِنِّي لَقِيتُ ابْنَ عَبَّاسٍ فَقُلْتُ أَخْبِرْنِي عَنْ هَذَا الَّذِي تَقُولُ فِي الصَّرْفِ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَمْ شَىْءٌ وَجَدْتَهُ فِي كِتَابِ اللَّهِ ‏.‏ فَقَالَ مَا وَجَدْتُهُ فِي كِتَابِ اللَّهِ وَلاَ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ وَلَكِنْ أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّمَا الرِّبَا فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{2257}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"I heard Abu Saeed Al-Khudri say: 'A Dirham for a Dirham and a Dinar for a Dinar.' So I said: 'I heard Ibn 'Abbas say something other than that.' He said: 'But I met Ibn 'Abbas and said: "Tell me about what you say concerning exchange is it something that you heard from the Messenger of Allah (ﷺ) or something that You found in the Book of Allah?" He said: "I did not find it in the Book of Allah, and I did not hear it from the Messenger of Allah; rather Usamah bin Zaid told me that the Messenger of Allah (ﷺ) said: "Usury is only in credit}}
\hadithdefcmd{ibnmajah}{2258}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سُلَيْمَانَ بْنِ عَلِيٍّ الرِّبْعِيِّ، عَنْ أَبِي الْجَوْزَاءِ، قَالَ سَمِعْتُهُ يَأْمُرُ، بِالصَّرْفِ - يَعْنِي ابْنَ عَبَّاسٍ - وَيُحَدَّثُ ذَلِكَ عَنْهُ ثُمَّ بَلَغَنِي أَنَّهُ رَجَعَ عَنْ ذَلِكَ فَلَقِيتُهُ بِمَكَّةَ فَقُلْتُ إِنَّهُ بَلَغَنِي أَنَّكَ رَجَعْتَ ‏.‏ قَالَ نَعَمْ إِنَّمَا كَانَ ذَلِكَ رَأْيًا مِنِّي وَهَذَا أَبُو سَعِيدٍ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ نَهَى عَنِ الصَّرْفِ ‏.‏\hadithno{2258}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Jawza' said:"I heard him meaning Ibn 'Abbas allowing exchange (of Dirhams for Dirham etc., if extra was given) and that was narrated from him. Then I heard that he has taken back this opinion. I met him in Makkah and said: 'I heard that you had taken back (your opinion).' He said: 'Yes. That was just my own opinion, but Abu Sa'eed narrated from the Messenger of Allah (ﷺ) that he forbade exchange (of like items if extra is given)}}
\hadithdefcmd{ibnmajah}{2259}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، سَمِعَ مَالِكَ بْنَ أَوْسِ بْنِ الْحَدَثَانِ، يَقُولُ سَمِعْتُ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الذَّهَبُ بِالْوَرِقِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ سَمِعْتُ سُفْيَانَ يَقُولُ الذَّهَبُ بِالْوَرِقِ احْفَظُوا ‏.‏\hadithno{2259}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zuhri heard Malik bin Aws bin Hadathan say:"I heard 'Umar say: "The Messenger of Allah (ﷺ), said: 'Gold for silver is usury, unless it is exchanged on the spot."' (Sahih) Abu Bakr bin Abu-Shaibah said: "I heard sufyan saying: 'Gold for silver." memorize (this)}}
\hadithdefcmd{ibnmajah}{2260}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ أَقْبَلْتُ أَقُولُ مَنْ يَصْطَرِفُ الدَّرَاهِمَ فَقَالَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ وَهُوَ عِنْدَ عُمَرَ بْنِ الْخَطَّابِ أَرِنَا ذَهَبَكَ ثُمَّ ائْتِنَا إِذَا جَاءَ خَازِنُنَا نُعْطِكَ وَرِقَكَ ‏.‏ فَقَالَ عُمَرُ كَلاَّ وَاللَّهِ لَتُعْطِيَنَّهُ وَرِقَهُ أَوْ لَتَرُدَّنَّ إِلَيْهِ ذَهَبَهُ فَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْوَرِقُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏ ‏.‏\hadithno{2260}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Malik bin Aws bin Hadathan said:"I came saying. 'Who will exchange Dirham?' Talhah bin 'Ubaidullah, who was with 'Umar bin Khattab, said: 'Show us your gold, then come to us; when our treasure comes, we will give you your silver.' 'Umar said: 'No, by Allah, you will give him silver (now), or give him back his gold, for the Messenger of Allah (ﷺ) said: "Silver for gold is usury, unless it is exchanged on the spot}}
\hadithdefcmd{ibnmajah}{2261}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ حَدَّثَنِي أَبِي، عَنْ أَبِيهِ الْعَبَّاسِ بْنِ عُثْمَانَ بْنِ شَافِعٍ، عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الدِّينَارُ بِالدِّينَارِ وَالدِّرْهَمُ بِالدِّرْهَمِ لاَ فَضْلَ بَيْنَهُمَا فَمَنْ كَانَتْ لَهُ حَاجَةٌ بِوَرِقٍ فَلْيَصْطَرِفْهَا بِذَهَبٍ وَمَنْ كَانَتْ لَهُ حَاجَةٌ بِذَهَبٍ فَلْيَصْطَرِفْهَا بِالْوَرِقِ وَالصَّرْفُ هَاءَ وَهَاءَ ‏"‏ ‏.‏\hadithno{2261}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umar bin Muhammad bin 'Ali bin abi Talib, from his father, that his grandfather said:'The Messenger of Allah (ﷺ) said: 'Dinar for Dinar, Dirham for Dirham, with no increase between them. Whoever has need of silver, let him trade gold for it, and whoever has need of gold, let him trade silver for it, and let the transaction be done on the spot}}
\hadithdefcmd{ibnmajah}{2262}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، وَسُفْيَانُ بْنُ وَكِيعٍ، وَمُحَمَّدُ بْنُ عُبَيْدِ بْنِ ثَعْلَبَةَ الْحِمَّانِيُّ، قَالُوا حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، أَوْ سِمَاكٌ - وَلاَ أَعْلَمُهُ إِلاَّ سِمَاكًا - عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ قَالَ كُنْتُ أَبِيعُ الإِبِلَ فَكُنْتُ آخُذُ الذَّهَبَ مِنَ الْفِضَّةِ وَالْفِضَّةَ مِنَ الذَّهَبِ وَالدَّنَانِيرَ مِنَ الدَّرَاهِمِ وَالدَّرَاهِمَ مِنَ الدَّنَانِيرِ ‏.‏ فَسَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِذَا أَخَذْتَ أَحَدَهُمَا وَأَعْطَيْتَ الآخَرَ فَلاَ تُفَارِقْ صَاحِبَكَ وَبَيْنَكَ وَبَيْنَهُ لَبْسٌ ‏"‏ ‏.‏ حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{2262}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"I used to sell camels, and I used to buy gold for silver and silver for gold, Dinar for Dirham and Dirham for Dinar. I asked the Prophet (ﷺ) about that, and he said: 'If you take one of them and give the other, then you and your companion should not separate until everything is clear (i.e., the exchange is completed).’” (Hasan) Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{2263}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَهَارُونُ بْنُ إِسْحَاقَ، قَالُوا أَنْبَأَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ فَضَاءٍ، عَنْ أَبِيهِ، عَنْ عَلْقَمَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ كَسْرِ سِكَّةِ الْمُسْلِمِينَ الْجَائِزَةِ بَيْنَهُمْ إِلاَّ مِنْ بَأْسٍ ‏"‏ ‏.‏\hadithno{2263}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Alqamah bin 'Abdullah that his father said:"The Messenger of Allah (ﷺ) forbade breaking the coins of the Muslims that are in circulation among them, without any necessary reason.”}}
\hadithdefcmd{ibnmajah}{2264}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، وَإِسْحَاقُ بْنُ سُلَيْمَانَ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ أَنَّ زَيْدًا أَبَا عَيَّاشٍ، - مَوْلًى لِبَنِي زُهْرَةَ - أَخْبَرَهُ أَنَّهُ، سَأَلَ سَعْدَ بْنَ أَبِي وَقَّاصٍ عَنِ اشْتِرَاءِ الْبَيْضَاءِ، بِالسُّلْتِ فَقَالَ لَهُ سَعْدٌ أَيَّتُهُمَا أَفْضَلُ قَالَ الْبَيْضَاءُ ‏.‏ فَنَهَانِي عَنْهُ وَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سُئِلَ عَنِ اشْتِرَاءِ الرُّطَبِ بِالتَّمْرِ فَقَالَ ‏ "‏ أَيَنْقُصُ الرُّطَبُ إِذَا يَبِسَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَنَهَى عَنْ ذَلِكَ ‏.‏\hadithno{2264}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Yazid, the freed slave of Al-Aswad bin Sufyan, that :Zaid, Abu 'Ayyash, the freed slave of Bani Zuhrah, told him that he asked Sa'd bin Abu Waqqas about buying wheat with barley. Sa'd said to him: "Which of them is better?" He said: "Wheat." He told him not to do that and said: "I heard the Messenger of Allah (ﷺ) being asked about buying fresh dates with dried dates, and he said: 'Do fresh dates decrease in weight when they become dry?' They said: 'Yes.' So he told them not to do that}}
\hadithdefcmd{ibnmajah}{2265}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمُزَابَنَةِ ‏.‏ وَالْمُزَابَنَةُ أَنْ يَبِيعَ الرَّجُلُ تَمْرَ حَائِطِهِ إِنْ كَانَتْ نَخْلاً بِتَمْرٍ كَيْلاً وَإِنْ كَانَتْ كَرْمًا أَنْ يَبِيعَهُ بِزَبِيبٍ كَيْلاً وَإِنْ كَانَتْ زَرْعًا أَنْ يَبِيعَهُ بِكَيْلِ طَعَامٍ نَهَى عَنْ ذَلِكَ كُلِّهِ ‏.‏\hadithno{2265}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abduilah bin 'Umar said:"The Messenger of Allah (ﷺ) forbade the Muzabanah. The Muzdbanah means when a man sells the dates of his grove when they are still on the tree, for a measure of dty dates;[2] or, if it is grapes, he sells them when they are still on the vine, for a measure of raisins; or if it is a crop, he sells it for food, estimating the amount (of the crop in the field). He forbade all of these things}}
\hadithdefcmd{ibnmajah}{2266}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، وَسَعِيدِ بْنِ مِينَاءَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏\hadithno{2266}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{lt was narrated from Sabir bin 'Abdullah that :the Messenger of Allah (ﷺ) forbade the Muhaqalah and the Muzabanah}}
\hadithdefcmd{ibnmajah}{2267}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ طَارِقِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏\hadithno{2267}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Rafi, bin Khadij said:"The Messenger of Allah (ﷺ) forbade the Muhaqalah and the Muzabanah}}
\hadithdefcmd{ibnmajah}{2268}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{2268}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim from his father:"Zaid bin Thabit narrated to me that the Messenger of Allah (ﷺ) gave a concession regarding the sale of 'Araya.”}}
\hadithdefcmd{ibnmajah}{2269}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَرْخَصَ فِي بَيْعِ الْعَرِيَّةِ بِخَرْصِهَا تَمْرًا ‏.‏ قَالَ يَحْيَى الْعَرِيَّةُ أَنْ يَشْتَرِيَ الرَّجُلُ ثَمَرَ النَّخَلاَتِ بِطَعَامِ أَهْلِهِ رُطَبًا بِخَرْصِهَا تَمْرًا ‏.‏\hadithno{2269}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that he said:"Zaid bin Thabit told me that the Messenger of Allah (ﷺ) gave a concession regarding the sale of the estimated harvest of 'Araya return for dried dates." (Sahih) Yahya (one of the narrators) said: "The 'Araya is when a man purchases dates on the trees for food that his family has that is ripe, by estimating them (the dates)}}
\hadithdefcmd{ibnmajah}{2270}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنْ بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً ‏.‏\hadithno{2270}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Samurah bin Jundub that :the Messenger of Allah (ﷺ) forbade selling animals for animals on credit}}
\hadithdefcmd{ibnmajah}{2271}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَأَبُو خَالِدٍ عَنْ حَجَّاجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ بَأْسَ الْحَيَوَانُ بِالْحَيَوَانِ وَاحِدًا بِاثْنَيْنِ يَدًا بِيَدٍ ‏"‏ ‏.‏ وَكَرِهَهُ نَسِيئَةً ‏.‏\hadithno{2271}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:"There is nothing wrong with selling animals, one for two, hand to hand," but he disliked selling them on credit}}
\hadithdefcmd{ibnmajah}{2272}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا الْحُسَيْنُ بْنُ عُرْوَةَ، ح وَحَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ عَمْرٍو حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اشْتَرَى صَفِيَّةَ بِسَبْعَةِ أَرْؤُسٍ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ مِنْ دِحْيَةَ الْكَلْبِيِّ ‏.‏\hadithno{2272}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that :the Prophet (ﷺ) bought Safiyyah for seven slaves. (Sahih) (One of the narrators) 'Abdur-Rahman said: "From Dihyah Kalbi}}
\hadithdefcmd{ibnmajah}{2273}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَبِي الصَّلْتِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَتَيْتُ لَيْلَةَ أُسْرِيَ بِي عَلَى قَوْمٍ بُطُونُهُمْ كَالْبُيُوتِ فِيهَا الْحَيَّاتُ تُرَى مِنْ خَارِجِ بُطُونِهِمْ فَقُلْتُ مَنْ هَؤُلاَءِ يَا جِبْرَائِيلُ قَالَ هَؤُلاَءِ أَكَلَةُ الرِّبَا ‏"‏ ‏.‏\hadithno{2273}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:' "'On the night in which I was taken on the Night Journey (Al-Isra'), I came to people whose stomachs were like houses, in which there were snakes that could be seen from outside their stomachs. I said: 'Who are these, O Jibra’il?’ He said: 'They are the ones who consumed usury}}
\hadithdefcmd{ibnmajah}{2274}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ أَبِي مَعْشَرٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الرِّبَا سَبْعُونَ حُوبًا أَيْسَرُهَا أَنْ يَنْكِحَ الرَّجُلُ أُمَّهُ ‏"‏ ‏.‏\hadithno{2274}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"There are seventy degrees of usury, the least of which is equivalent to a man having intercourse with his mother}}
\hadithdefcmd{ibnmajah}{2275}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ الصَّيْرَفِيُّ أَبُو حَفْصٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الرِّبَا ثَلاَثَةٌ وَسَبْعُونَ بَابًا ‏"‏ ‏.‏\hadithno{2275}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah that the Prophet (ﷺ) said:"There are seventy-three degrees of usury}}
\hadithdefcmd{ibnmajah}{2276}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ إِنَّ آخِرَ مَا نَزَلَتْ آيَةُ الرِّبَا وَإِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قُبِضَ وَلَمْ يُفَسِّرْهَا لَنَا فَدَعُوا الرِّبَا وَالرِّيبَةَ ‏.‏\hadithno{2276}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Umar bin Khattab said:"The last thing to be revealed was the Verse on usury but the Messenger of Allah (ﷺ) died before he had explained it to us. So give up usury (interest) and doubtful things}}
\hadithdefcmd{ibnmajah}{2277}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَعَنَ آكِلَ الرِّبَا وَمُوكِلَهُ وَشَاهِدَيْهِ وَكَاتِبَهُ ‏.‏\hadithno{2277}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that :Xthe Messenger of Allah (ﷺ) cursed the one who consumes usury, the one who pays it, those who witness it and the one who writes it down}}
\hadithdefcmd{ibnmajah}{2278}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ سَعِيدِ بْنِ أَبِي خَيْرَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ لاَ يَبْقَى مِنْهُمْ أَحَدٌ إِلاَّ أَكَلَ الرِّبَا فَمَنْ لَمْ يَأْكُلْ أَصَابَهُ مِنْ غُبَارِهِ ‏"‏ ‏.‏\hadithno{2278}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There will come a time when there will be no one left who does not consume usury (interest), and whoever does not consume it will nevertheless be affected by it}}
\hadithdefcmd{ibnmajah}{2279}{حَدَّثَنَا الْعَبَّاسُ بْنُ جَعْفَرٍ، حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، عَنْ إِسْرَائِيلَ، عَنْ رُكَيْنِ بْنِ الرَّبِيعِ بْنِ عَمِيلَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا أَحَدٌ أَكْثَرَ مِنَ الرِّبَا إِلاَّ كَانَ عَاقِبَةُ أَمْرِهِ إِلَى قِلَّةٍ ‏"‏ ‏.‏\hadithno{2279}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn Mas'ud that the Prophet (ﷺ) said:"There is no one who deals in usury a great deal (to increase his wealth) but he will end up with little (i.e., his wealth will be decreased)}}
\hadithdefcmd{ibnmajah}{2280}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَهُمْ يُسْلِفُونَ فِي التَّمْرِ السَّنَتَيْنِ وَالثَّلاَثَ فَقَالَ ‏ "‏ مَنْ أَسْلَفَ فِي تَمْرٍ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{2280}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"When the Prophet (ﷺ) came (to Al-Madinah), they used to pay in advance for dates, two or three years in advance. He said: 'Whoever pays in advance for dates, let him pay for a known amount or a known weight, to be delivered at a known time.’”}}
\hadithdefcmd{ibnmajah}{2281}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ حَمْزَةَ بْنِ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ إِنَّ بَنِي فُلاَنٍ أَسْلَمُوا - لِقَوْمٍ مِنَ الْيَهُودِ - وَإِنَّهُمْ قَدْ جَاعُوا فَأَخَافُ أَنْ يَرْتَدُّوا ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ عِنْدَهُ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْيَهُودِ عِنْدِي كَذَا وَكَذَا - لِشَىْءٍ قَدْ سَمَّاهُ أُرَاهُ قَالَ ثَلاَثُمِائَةِ دِينَارٍ بِسِعْرِ كَذَا وَكَذَا مِنْ حَائِطِ بَنِي فُلاَنٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ بِسِعْرِ كَذَا وَكَذَا إِلَى أَجَلِ كَذَا وَكَذَا وَلَيْسَ مِنْ حَائِطِ بَنِي فُلاَنٍ ‏"‏ ‏.‏\hadithno{2281}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muhammad bin Hamzah bin Yusuf bin 'Abdullah bin Salam, from his father, that his grandfather 'Abdullah bin Salam said:"A man came to the Prophet (ﷺ) and said, 'The tribe of Banu so-and- so, who were descended from the Jews, have become Muslim, and they are starving, and I am afraid that they may apostatize.' The Prophet (ﷺ) said: 'Who has something with him?' A Jewish man said: 'I have such and such, and he named it, and I think he said three hundred Dinar for such and such 'an amount (of produce) from the garden of the tribe of Banu so-and-so.' The Messenger of Allah (ﷺ) said: 'For such and such a price at such and such a time, but not from the garden of the tribe of Banu so-and- so}}
\hadithdefcmd{ibnmajah}{2282}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، - قَالَ يَحْيَى عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْمُجَالِدِ، وَقَالَ عَبْدُ الرَّحْمَنِ، عَنِ ابْنِ أَبِي الْمُجَالِدِ، - قَالَ امْتَرَى عَبْدُ اللَّهِ بْنُ شَدَّادٍ وَأَبُو بُرْدَةَ فِي السَّلَمِ فَأَرْسَلُونِي إِلَى عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى فَسَأَلْتُهُ فَقَالَ كُنَّا نُسْلِمُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَعَهْدِ أَبِي بَكْرٍ وَعُمَرَ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالزَّبِيبِ وَالتَّمْرِ عِنْدَ قَوْمٍ مَا عِنْدَهُمْ ‏.‏ فَسَأَلْتُ ابْنَ أَبْزَى فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{2282}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Mujalid said:"Abdullah bin Shaddad and Abu Barzah had a dispute about paying in advance. They sent me to 'Abdullah bin Abu Awfa to ask him about it. He said: 'We used to make payments in advance at the time of the Messenger of Allah (ﷺ) and the time of Abu Bakr and 'Umar, for wheat, barley, raisins and dates, to people who did not yet possess those things.' I asked Ibn Abza, and he said something similar}}
\hadithdefcmd{ibnmajah}{2283}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، حَدَّثَنَا زِيَادُ بْنُ خَيْثَمَةَ، عَنْ سَعْدٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَسْلَفْتَ فِي شَىْءٍ فَلاَ تَصْرِفْهُ إِلَى غَيْرِهِ ‏"‏ ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، عَنْ زِيَادِ بْنِ خَيْثَمَةَ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَكَرَ مِثْلَهُ وَلَمْ يَذْكُرْ سَعْدًا ‏.‏\hadithno{2283}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed that the Messenger of Allah (ﷺ) said:"When you have paid in advance for something, do not exchange it for something else." (Da'if)Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{2284}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ النَّجْرَانِيِّ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ عُمَرَ أُسْلِمُ فِي نَخْلٍ قَبْلَ أَنْ يُطْلِعَ قَالَ لاَ ‏.‏ قُلْتُ لِمَ قَالَ إِنَّ رَجُلاً أَسْلَمَ فِي حَدِيقَةِ نَخْلٍ فِي عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَبْلَ أَنْ يُطْلِعَ النَّخْلُ فَلَمْ يُطْلِعِ النَّخْلُ شَيْئًا ذَلِكَ الْعَامَ فَقَالَ الْمُشْتَرِي هُوَ لِي حَتَّى يُطْلِعَ ‏.‏ وَقَالَ الْبَائِعُ إِنَّمَا بِعْتُكَ النَّخْلَ هَذِهِ السَّنَةَ ‏.‏ فَاخْتَصَمَا إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لِلْبَائِعِ ‏"‏ أَخَذَ مِنْ نَخْلِكَ شَيْئًا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَبِمَ تَسْتَحِلُّ مَالَهُ ارْدُدْ عَلَيْهِ مَا أَخَذْتَ مِنْهُ وَلاَ تُسْلِمُوا فِي نَخْلٍ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏.‏\hadithno{2284}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Najrani said:"I said to 'Abdullah bin 'Umar: 'Can I pay in advance for a date palm before it bears fruit?' He said: 'No.' I said: 'Why not?' He said: 'A man paid in advance for a grove of trees during the time of the Messenger of Allah (ﷺ), before they had produced any fruit, and they did not bear anything that year. The purchaser said: 'They belong to me until they produce but the seller said: 'I only sold the trees to you for this year! They referred their dispute to the Messenger of Allah who said to the seller: 'Did he take anything from your date palms?' He said: 'No.' He said: 'Then why do you regard his wealth as lawful for You? Give back what you took from him, and do not take payment in advance for date palms until their usefulness appears}}
\hadithdefcmd{ibnmajah}{2285}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُسْلِمُ بْنُ خَالِدٍ، حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ اسْتَسْلَفَ مِنْ رَجُلٍ بَكْرًا وَقَالَ ‏"‏ إِذَا جَاءَتْ إِبِلُ الصَّدَقَةِ قَضَيْنَاكَ ‏"‏ ‏.‏ فَلَمَّا قَدِمَتْ قَالَ ‏"‏ يَا أَبَا رَافِعٍ اقْضِ هَذَا الرَّجُلَ بَكْرَهُ ‏"‏ ‏.‏ فَلَمْ أَجِدْ إِلاَّ رَبَاعِيًا فَصَاعِدًا فَأَخْبَرْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ أَعْطِهِ فَإِنَّ خَيْرَ النَّاسِ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{2285}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Rafi' that:the Prophet (ﷺ) asked a man to give as a loan a young camel and said: “When the camels of the Sadaqah come, we will pay you back.” When the camels came, he said: " O Abu Rafi', pay this man back for his Young camel." But all I could find was a seven-year-old camel or that which is better. I told the Prophet (ﷺ) and he said: "Give it to him, for the best of People are those who are best in repaying}}
\hadithdefcmd{ibnmajah}{2286}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنِي سَعِيدُ بْنُ هَانِئٍ، قَالَ سَمِعْتُ الْعِرْبَاضَ بْنَ سَارِيَةَ، يَقُولُ كُنْتُ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ أَعْرَابِيٌّ اقْضِنِي بَكْرِي ‏.‏ فَأَعْطَاهُ بَعِيرًا مُسِنًّا فَقَالَ الأَعْرَابِيُّ يَا رَسُولَ اللَّهِ هَذَا أَسَنُّ مِنْ بَعِيرِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ النَّاسِ خَيْرُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{2286}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'eed bin Hani' said:"I heard 'Irbad bin Sariyah say: 'I was with the Prophet (ﷺ) and a Bedouin said: "Pay me back for my young camel, and he gave him an older (i.e., better) camel." He said: 'O Messenger of Allah! It is older (i.e., better) than my camel.' The Messenger of Allah (ﷺ) said: 'The best of people are those who are best in repaying}}
\hadithdefcmd{ibnmajah}{2287}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ مُجَاهِدٍ، عَنْ قَائِدِ السَّائِبِ، عَنِ السَّائِبِ، قَالَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ كُنْتَ شَرِيكِي فِي الْجَاهِلِيَّةِ فَكُنْتَ خَيْرَ شَرِيكٍ كُنْتَ لاَ تُدَارِينِي وَكُنْتَ لاَ تُمَارِينِي ‏.‏\hadithno{2287}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'ib said to the Prophet (ﷺ):"You were my partner during the Ignorance period and you were the best of partners, you did not contend or dispute}}
\hadithdefcmd{ibnmajah}{2288}{حَدَّثَنَا أَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ اشْتَرَكْتُ أَنَا وَسَعْدٌ، وَعَمَّارٌ، يَوْمَ بَدْرٍ فِيمَا نُصِيبُ فَلَمْ أَجِئْ أَنَا وَلاَ عَمَّارٌ بِشَىْءٍ وَجَاءَ سَعْدٌ بِرَجُلَيْنِ ‏.‏\hadithno{2288}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:"Sa'd, 'Ammar and I entered into a partnership on the day of Badr, (agreeing to share) whatever was allotted to us. 'Ammar and I did not get anything, but Sa'd got two men (slaves)}}
\hadithdefcmd{ibnmajah}{2289}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا بِشْرُ بْنُ ثَابِتٍ الْبَزَّارُ، حَدَّثَنَا نَصْرُ بْنُ الْقَاسِمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ دَاوُدَ، عَنْ صَالِحِ بْنِ صُهَيْبٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثٌ فِيهِنَّ الْبَرَكَةُ الْبَيْعُ إِلَى أَجَلٍ وَالْمُقَارَضَةُ وَإِخْلاَطُ الْبُرِّ بِالشَّعِيرِ لِلْبَيْتِ لاَ لِلْبَيْعِ ‏"‏ ‏.‏\hadithno{2289}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{lt was narrated from Salih bin Suhaib that his father said:"The Messenger of Allah (ﷺ) said: 'There are three things in which there is blessing: A sale with deferred payment; Muqaradhah (profit sharing); and mixing wheat with barley for one's house, but not for sale}}
\hadithdefcmd{ibnmajah}{2290}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَمَّتِهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلْتُمْ مِنْ كَسْبِكُمْ وَإِنَّ أَوْلاَدَكُمْ مِنْ كَسْبِكُمْ ‏"‏ ‏.‏\hadithno{2290}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"The best of your provision is what you earn, and your children are part of what you earn}}
\hadithdefcmd{ibnmajah}{2291}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا يُوسُفُ بْنُ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً وَوَلَدًا وَإِنَّ أَبِي يُرِيدُ أَنْ يَجْتَاحَ مَالِي فَقَالَ ‏ "‏ أَنْتَ وَمَالُكَ لأَبِيكَ ‏"‏ ‏.‏\hadithno{2291}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that a man said:"O Messenger of Allah, I have wealth and a son, and my father wants to take all my wealth." He said: "You and your wealth belong to your father}}
\hadithdefcmd{ibnmajah}{2292}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَيَحْيَى بْنُ حَكِيمٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَجَّاجٌ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ إِنَّ أَبِي اجْتَاحَ مَالِي ‏.‏ فَقَالَ ‏"‏ أَنْتَ وَمَالُكَ لأَبِيكَ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ أَوْلاَدَكُمْ مِنْ أَطْيَبِ كَسْبِكُمْ فَكُلُوا مِنْ أَمْوَالِهِمْ ‏"‏ ‏.‏\hadithno{2292}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"A man came to the Messenger of Allah (ﷺ), and said: 'My father is taking all my wealth.' He said: 'You and your wealth belong to your father.' And the Messenger of Allah (ﷺ) said: 'Your children are among the best of your earnings, so eat from your wealth.’”}}
\hadithdefcmd{ibnmajah}{2293}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو عُمَرَ الضَّرِيرُ قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ هِنْدٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ وَلاَ يُعْطِينِي مَا يَكْفِينِي وَوَلَدِي إِلاَّ مَا أَخَذْتُ مِنْ مَالِهِ وَهُوَ لاَ يَعْلَمُ ‏.‏ فَقَالَ ‏ "‏ خُذِي مَا يَكْفِيكِ وَوَلَدَكِ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{2293}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:'Hind came to the Prophet (ﷺ) and said: 'O Messenger of Allah, Abu Sufyan is a stingy man and he does not give me enough for me and my child, except for what I take from his wealth without him realizing.' He said: Take what is sufficient for you and your child, on a reasonable basis}}
\hadithdefcmd{ibnmajah}{2294}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ - وَقَالَ أَبِي فِي حَدِيثِهِ إِذَا أَطْعَمَتِ الْمَرْأَةُ - مِنْ بَيْتِ زَوْجِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُهَا وَلَهُ مِثْلُهُ بِمَا اكْتَسَبَ وَلَهَا بِمَا أَنْفَقَتْ وَلِلْخَازِنِ مِثْلُ ذَلِكَ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُوِرِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{2294}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"When a woman spends" and my father said: - "When a woman feeds (the poor) from her husband's house, without spending too much, she will have her reward, and he will be rewarded likewise because he earned it , and she will be rewarded for what she spent. The same applies to the storekeeper, without anything being detracted from their rewards.”}}
\hadithdefcmd{ibnmajah}{2295}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي شُرَحْبِيلُ بْنُ مُسْلِمٍ الْخَوْلاَنِيُّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ لاَ تُنْفِقُ الْمَرْأَةُ مِنْ بَيْتِهَا شَيْئًا إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلاَ الطَّعَامَ قَالَ ‏"‏ ذَلِكَ أَفْضَلُ أَمْوَالِنَا ‏"‏ ‏.‏\hadithno{2295}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shurahbil bin Muslim Al-Khawlani said:I heard Abu Umamah Al-Bahili say: I heard the Messenger of Allah (ﷺ) say: " No woman should spend anything from her house without her husband's permission." They said: "O Messenger of Allah, not even food?" He said: "That is among the best of our wealth}}
\hadithdefcmd{ibnmajah}{2296}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُسْلِمٍ الْمُلاَئِيِّ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُجِيبُ دَعْوَةَ الْمَمْلُوكِ ‏.‏\hadithno{2296}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Muslim Al-Mula'i that he heard Anas bin Malik say:"The Messenger of Allah (ﷺ) used to accept the invitation of a slave}}
\hadithdefcmd{ibnmajah}{2297}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ عُمَيْرٍ، - مَوْلَى آبِي اللَّحْمِ - قَالَ كَانَ مَوْلاَىَ يُعْطِينِي الشَّىْءَ فَأُطْعِمُ مِنْهُ فَمَنَعَنِي - أَوْ قَالَ فَضَرَبَنِي - فَسَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَوْ سَأَلَهُ فَقُلْتُ لاَ أَنْتَهِي أَوْ لاَ أَدَعُهُ ‏.‏ فَقَالَ ‏ "‏ الأَجْرُ بَيْنَكُمَا ‏"‏ ‏.‏\hadithno{2297}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Umair, the freed slave of Aabi Lahm, said:"My master used to give me food and I would feed others from it, then he stopped me," or he said: "He beat me. So I asked the Prophet,” -or- "he asked him and I said: 'I will not stop.' He said: 'Both of you will be rewarded}}
\hadithdefcmd{ibnmajah}{2298}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، جَعْفَرِ بْنِ إِيَاسٍ قَالَ سَمِعْتُ عَبَّادَ بْنَ شُرَحْبِيلَ، - رَجُلاً مِنْ بَنِي غُبَرَ - قَالَ أَصَابَنَا عَامُ مَخْمَصَةٍ فَأَتَيْتُ الْمَدِينَةَ فَأَتَيْتُ حَائِطًا مِنْ حِيطَانِهَا فَأَخَذْتُ سُنْبُلاً فَفَرَكْتُهُ وَأَكَلْتُهُ وَجَعَلْتُهُ فِي كِسَائِي فَجَاءَ صَاحِبُ الْحَائِطِ فَضَرَبَنِي وَأَخَذَ ثَوْبِي فَأَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَخْبَرْتُهُ فَقَالَ لِلرَّجُلِ ‏ "‏ مَا أَطْعَمْتَهُ إِذْ كَانَ جَائِعًا أَوْ سَاغِبًا وَلاَ عَلَّمْتَهُ إِذْ كَانَ جَاهِلاً ‏"‏ ‏.‏ فَأَمَرَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَرَدَّ إِلَيْهِ ثَوْبَهُ وَأَمَرَ لَهُ بِوَسْقٍ مِنْ طَعَامٍ أَوْ نِصْفِ وَسْقٍ ‏.‏\hadithno{2298}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Bishr Ja'far bin Abu Jyas said:“I heard 'Abbad bin Shurahbil, a man from Banu Ghubar, say: ‘We suffered a year of famine, and I came to Al-Madinah. I came to one of its gardens and took an ear of corn, I rubbed it, ate some and put the rest in my garment. The owner of the garden came and beat me and took my garment. I came to the Prophet (ﷺ) and told him (what had happened). He said to the man: "You did not feed him when he was hungry and you did not teach him when he was ignorant."' Then the Prophet (ﷺ) told him to give back his garment and ordered that a Wasq or half a Wasq of food be brought to him}}
\hadithdefcmd{ibnmajah}{2299}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، قَالاَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ ابْنَ أَبِي الْحَكَمِ الْغِفَارِيَّ، قَالَ حَدَّثَتْنِي جَدَّتِي، عَنْ عَمِّ، أَبِيهَا رَافِعِ بْنِ عَمْرٍو الْغِفَارِيِّ قَالَ كُنْتُ وَأَنَا غُلاَمٌ، أَرْمِي نَخْلَنَا - أَوْ قَالَ نَخْلَ الأَنْصَارِ - فَأُتِيَ بِيَ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا غُلاَمُ - وَقَالَ ابْنُ كَاسِبٍ فَقَالَ يَا بُنَىَّ - لِمَ تَرْمِي النَّخْلَ ‏"‏ ‏.‏ قَالَ قُلْتُ آكُلُ ‏.‏ قَالَ ‏"‏ فَلاَ تَرْمِي النَّخْلَ وَكُلْ مِمَّا يَسْقُطُ فِي أَسَافِلِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ مَسَحَ رَأْسِي وَقَالَ ‏"‏ اللَّهُمَّ أَشْبِعْ بَطْنَهُ ‏"‏ ‏.‏\hadithno{2299}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rafi' bin 'Amr Al-Ghifari said:"When I was a boy, I used to throw stones at our date-palm trees"[1] - or he said: "the date-palm trees of the Ansar." I was brought to the Prophet (ﷺ) and he said: 'O boy' - (one of the narrators) Ibn Kasib said: He said: 'O my son - why are you throwing stones at the date-palm trees?' I said: 'So I can eat.' He said: 'Do not throw stones at the date-palm trees. Eat from what falls to the ground from them.' Then he patted me on the head and said: 'O Allah give him enough to eat.'”}}
\hadithdefcmd{ibnmajah}{2300}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا أَتَيْتَ عَلَى رَاعٍ فَنَادِهِ ثَلاَثَ مِرَارٍ فَإِنْ أَجَابَكَ وَإِلاَّ فَاشْرَبْ فِي غَيْرِ أَنْ تُفْسِدَ وَإِذَا أَتَيْتَ عَلَى حَائِطِ بُسْتَانٍ فَنَادِ صَاحِبَ الْبُسْتَانِ ثَلاَثَ مَرَّاتٍ فَإِنْ أَجَابَكَ وَإِلاَّ فَكُلْ فِي أَنْ لاَ تُفْسِدَ ‏"‏ ‏.‏\hadithno{2300}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed that the Prophet (ﷺ) said:"When you come to a shepherd, call him three times. If he answers (all well and good), otherwise drink (milk from the flock) without taking advantage. And when you come to a garden call the owner of the garden three times. If he answers (all well and good), otherwise eat (from the produce of the garden) without taking advantage}}
\hadithdefcmd{ibnmajah}{2301}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، وَأَيُّوبُ بْنُ حَسَّانَ الْوَاسِطِيُّ، وَعَلِيُّ بْنُ سَلَمَةَ، قَالُوا حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا مَرَّ أَحَدُكُمْ بِحَائِطٍ فَلْيَأْكُلْ وَلاَ يَتَّخِذْ خُبْنَةً ‏"‏ ‏.‏\hadithno{2301}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"When anyone of you passes by a garden let him eat therefrom, but he should not carry any away in his garment}}
\hadithdefcmd{ibnmajah}{2302}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَامَ فَقَالَ ‏ "‏ لاَ يَحْتَلِبَنَّ أَحَدُكُمْ مَاشِيَةَ رَجُلٍ بِغَيْرِ إِذْنِهِ أَيُحِبُّ أَحَدُكُمْ أَنْ تُؤْتَى مَشْرُبَتُهُ فَيُكْسَرَ بَابُ خِزَانَتِهِ فَيُنْتَثَلَ طَعَامُهُ فَإِنَّمَا تَخْزُنُ لَهُمْ ضُرُوعُ مَوَاشِيهِمْ أَطْعِمَاتِهِمْ فَلاَ يَحْتَلِبَنَّ أَحَدُكُمْ مَاشِيَةَ امْرِئٍ بِغَيْرِ إِذْنِهِ ‏"‏ ‏.‏\hadithno{2302}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah (ﷺ) stood up and said:"No one of you should milk from the livestock of another man without his permission. Would anyone of you like someone to break into his storeroom and take his food? The udders of their livestock store food for them, so none of you should milk the livestock of another man without his permission}}
\hadithdefcmd{ibnmajah}{2303}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ بِشْرِ بْنِ مَنْصُورٍ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، عَنْ حَجَّاجٍ، عَنْ سَلِيطِ بْنِ عَبْدِ اللَّهِ الطُّهَوِيِّ، عَنْ ذُهَيْلِ بْنِ عَوْفِ بْنِ شَمَّاخٍ الطُّهَوِيِّ، حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ إِذْ رَأَيْنَا إِبِلاً مَصْرُورَةً بِعِضَاهِ الشَّجَرِ فَثُبْنَا إِلَيْهَا فَنَادَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَرَجَعْنَا إِلَيْهِ فَقَالَ ‏"‏ إِنَّ هَذِهِ الإِبِلَ لأَهْلِ بَيْتٍ مِنَ الْمُسْلِمِينَ هُوَ قُوتُهُمْ وَيُمْنُهُمْ بَعْدَ اللَّهِ أَيَسُرُّكُمْ لَوْ رَجَعْتُمْ إِلَى مَزَاوِدِكُمْ فَوَجَدْتُمْ مَا فِيهَا قَدْ ذُهِبَ بِهِ أَتُرَوْنَ ذَلِكَ عَدْلاً ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَإِنَّ هَذَا كَذَلِكَ ‏"‏ ‏.‏ قُلْنَا أَفَرَأَيْتَ إِنِ احْتَجْنَا إِلَى الطَّعَامِ وَالشَّرَابِ فَقَالَ ‏"‏ كُلْ وَلاَ تَحْمِلْ وَاشْرَبْ وَلاَ تَحْمِلْ ‏"‏ ‏.‏\hadithno{2303}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:“While we were with the Messenger of Allah (ﷺ) on a journey, we saw some camels with their udders tied, among some thorny trees. We rushed towards it, but the Messenger of Allah (ﷺ) called us and we came back to him. He said: 'These camels belong to a family of Muslims, and this is their support (and blessing) after Allah. Would you be happy if you went back to your vessels and found that what was in them had been taken away? Do you think that is fair?' They said: 'No.' He said: 'This is like that.' We said: 'What do you think if we are in need of food and drink?' He said: 'Eat but do not carry any away: drink but do not carry any away}}
\hadithdefcmd{ibnmajah}{2304}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ هَانِئٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ لَهَا ‏ "‏ اتَّخِذِي غَنَمًا فَإِنَّ فِيهَا بَرَكَةً ‏"‏ ‏.‏\hadithno{2304}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Umm Hani' that the Prophet (ﷺ) said to her:"Keep sheep, for in them is blessing}}
\hadithdefcmd{ibnmajah}{2305}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ عَامِرٍ، عَنْ عُرْوَةَ الْبَارِقِيِّ، يَرْفَعُهُ قَالَ ‏ "‏ الإِبِلُ عِزٌّ لأَهْلِهَا وَالْغَنَمُ بَرَكَةٌ وَالْخَيْرُ مَعْقُودٌ فِي نَوَاصِي الْخَيْلِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2305}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Urwah Al-Bariqi said in a Marfu’ report:"Camels are the pride of their owners, and sheep are a blessing, and goodness is tied to the forelocks of horses until the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{2306}{حَدَّثَنَا عِصْمَةُ بْنُ الْفَضْلِ النَّيْسَابُورِيُّ، وَمُحَمَّدُ بْنُ فِرَاسٍ أَبُو هُرَيْرَةَ الصَّيْرَفِيُّ، قَالاَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا زَرْبِيٌّ، إِمَامُ مَسْجِدِ هِشَامِ بْنِ حَسَّانَ حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنِ ابْنِ عُمَرَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الشَّاةُ مِنْ دَوَابِّ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2306}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Sheep are among the animals of Paradise}}
\hadithdefcmd{ibnmajah}{2307}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عَلِيُّ بْنُ عُرْوَةَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الأَغْنِيَاءَ بِاتِّخَاذِ الْغَنَمِ وَأَمَرَ الْفُقَرَاءَ بِاتِّخَاذِ الدَّجَاجِ وَقَالَ ‏ "‏ عِنْدَ اتِّخَاذِ الأَغْنِيَاءِ الدَّجَاجَ يَأْذَنُ اللَّهُ بِهَلاَكِ الْقُرَى ‏"‏ ‏.‏\hadithno{2307}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) commanded the rich to keep sheep, and he commanded the poor to keep chickens, and he said: 'When the rich keep chickens, then Allah will give permission for the town to be destroyed}}
